@@ -1,49 +1,53 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
 """ Basic action list tool.
 
-$Id: ActionsTool.py,v 1.27.10.6 2002/08/30 14:44:27 tseaver Exp $
+$Id: ActionsTool.py,v 1.39.4.4 2004/04/26 14:52:01 tseaver Exp $
 """
+
 from Globals import InitializeClass, DTMLFile, package_home
 from Acquisition import aq_base, aq_inner, aq_parent
 from AccessControl import ClassSecurityInfo
 from OFS.Folder import Folder
 from OFS.SimpleItem import SimpleItem
 
-from CMFCorePermissions import ManagePortal
 from Expression import Expression, createExprContext
 from ActionInformation import ActionInformation, oai
 from ActionProviderBase import ActionProviderBase
 from TypesTool import TypeInformation
-
-from utils import UniqueObject
-from utils import SimpleItemWithProperties
-from utils import _getAuthenticatedUser
+from CMFCorePermissions import ManagePortal
 from utils import _checkPermission
-from utils import getToolByName
 from utils import _dtmldir
-from utils import cookString
+from utils import SimpleItemWithProperties
+from utils import UniqueObject
+
+from interfaces.portal_actions import portal_actions as IActionsTool
+
 
 class ActionsTool(UniqueObject, Folder, ActionProviderBase):
     """
         Weave together the various sources of "actions" which are apropos
         to the current user and context.
     """
+
+    __implements__ = (IActionsTool, ActionProviderBase.__implements__)
+
     id = 'portal_actions'
-    _actions = [ActionInformation(id='folderContents'
+    meta_type = 'CMF Actions Tool'
+    _actions = (ActionInformation(id='folderContents'
                                 , title='Folder contents'
                                 , action=Expression(
-               text='string: ${folder_url}/folder_contents')
+               text='string:${folder_url}/folder_contents')
                                 , condition=Expression(
                text='python: folder is not object') 
                                 , permissions=('List folder contents',)
@@ -53,19 +57,19 @@ class ActionsTool(UniqueObject, Folder, ActionProviderBase):
               , ActionInformation(id='folderContents'
                                 , title='Folder contents'
                                 , action=Expression(
-               text='string: ${folder_url}/folder_contents')
+               text='string:${folder_url}/folder_contents')
                                 , condition=Expression(
                text='python: folder is object')
                                 , permissions=('List folder contents',)
                                 , category='folder'
                                 , visible=1
-                                 )]
-
-    meta_type = 'CMF Actions Tool'
+                                 )
+               )
 
     action_providers = ( 'portal_membership'
                        , 'portal_actions'
                        , 'portal_registration'
+                       , 'portal_types'
                        , 'portal_discussion'
                        , 'portal_undo'
                        , 'portal_syndication'
@@ -82,25 +86,23 @@ class ActionsTool(UniqueObject, Folder, ActionProviderBase):
                        , { 'label' : 'Overview'
                          , 'action' : 'manage_overview'
                          }
-                       )
-                     + Folder.manage_options
+                     ) + Folder.manage_options
                      ) 
 
     #
     #   ZMI methods
     #
-    security.declareProtected( ManagePortal, 'manage_overview' )
+    security.declareProtected(ManagePortal, 'manage_overview')
     manage_overview = DTMLFile( 'explainActionsTool', _dtmldir )
     manage_actionProviders = DTMLFile('manageActionProviders', _dtmldir)
 
-    security.declareProtected( ManagePortal, 'manage_aproviders' )
-    def manage_aproviders( self
-                         , apname=''
-                         , chosen=()
-                         , add_provider=0
-                         , del_provider=0
-                         , REQUEST=None
-                         ):
+    security.declareProtected(ManagePortal, 'manage_aproviders')
+    def manage_aproviders(self
+                        , apname=''
+                        , chosen=()
+                        , add_provider=0
+                        , del_provider=0
+                        , REQUEST=None):
         """
         Manage action providers through-the-web.
         """
@@ -115,57 +117,48 @@ class ActionsTool(UniqueObject, Folder, ActionProviderBase):
             providers = new_providers
         self.action_providers = tuple(providers)
         if REQUEST is not None:
-            return self.manage_actionProviders( self , REQUEST
-                          , manage_tabs_message='Properties changed.')
+            return self.manage_actionProviders(self , REQUEST
+                          , manage_tabs_message='Providers changed.')
 
     #
-    #   ActionProvider interface
+    #   Programmatically manipulate the list of action providers
     #
-    security.declarePrivate('listActions')
-    def listActions(self, info=None):
-        """
-        Return a list of actions available through the tool.
-        """
-        return self._actions
-
-    #
-    # Programmatically manipulate the list of action providers
-    #
-    security.declareProtected( ManagePortal, 'listActionProviders' )
+    security.declareProtected(ManagePortal, 'listActionProviders')
     def listActionProviders(self):
-       """
-       Return a sequence of names of action providers known by this tool.
-       """
-       return self.action_providers
+        """
+        Return a sequence of action providers known by this tool.
+        """
+        return self.action_providers
 
-    security.declareProtected( ManagePortal, 'addActionProvider' )
+    security.declareProtected(ManagePortal, 'addActionProvider')
     def addActionProvider( self, provider_name ):
         """
         Add the name of a new action provider.
         """
-        ap = list( self.action_providers )[:]
+        ap = list( self.action_providers )
         if hasattr( self, provider_name ) and provider_name not in ap:
             ap.append( provider_name )
             self.action_providers = tuple( ap )
 
-    security.declareProtected( ManagePortal, 'deleteActionProvider' )
+    security.declareProtected(ManagePortal, 'deleteActionProvider')
     def deleteActionProvider( self, provider_name ):
         """
         Remove an action provider.
         """
-        if provider_name in self.action_providers:
-            ap = list( self.action_providers )
+        ap = list( self.action_providers )
+        if provider_name in ap:
             ap.remove( provider_name )
             self.action_providers = tuple( ap )
 
     #
     #   'portal_actions' interface methods
     #
-    security.declarePublic( 'listFilteredActionsFor' )
+    security.declarePublic('listFilteredActionsFor')
     def listFilteredActionsFor(self, object=None):
-        '''Gets all actions available to the user and returns a mapping
-        containing user actions, object actions, and global actions.
-        '''
+        """
+        Return a mapping containing of all actions available to the
+        user against object, bucketing into categories.
+        """
         portal = aq_parent(aq_inner(self))
         if object is None or not hasattr(object, 'aq_base'):
             folder = portal
@@ -183,6 +176,7 @@ class ActionsTool(UniqueObject, Folder, ActionProviderBase):
         actions = []
         append = actions.append
         info = oai(self, folder, object)
+
         # Include actions from specific tools.
         for provider_name in self.listActionProviders():
             provider = getattr(self, provider_name)
@@ -191,27 +185,6 @@ class ActionsTool(UniqueObject, Folder, ActionProviderBase):
         # Include actions from object.
         if object is not None:
             base = aq_base(object)
-            types_tool = getToolByName( self, 'portal_types' )
-            # we might get None back from getTypeInfo.  We construct
-            # a dummy TypeInformation object here in that case (the 'or'
-            # case).  This prevents us from needing to check the condition.
-            ti = types_tool.getTypeInfo( object ) or TypeInformation('Dummy')
-            defs = ti.getActions()
-            url = object_url = object.absolute_url()
-            for d in defs:
-                # we can't modify or expose the original actionsd... this
-                # stems from the fact that getActions returns a ref to the
-                # actual dictionary used to store actions instead of a
-                # copy.  We copy it here to prevent it from being modified.
-                d = d.copy()
-                d['id'] = d.get('id', None)
-                if d['action']:
-                    url = '%s/%s' % (object_url, d['action'])
-                d['url'] = url
-                d['category'] = d.get('category', 'object')
-                d['visible'] = d.get('visible', 1)
-                actions.append(d)
-
             if hasattr(base, 'listActions'):
                 self._listActions(append,object,info,ec)
 
@@ -234,6 +207,9 @@ class ActionsTool(UniqueObject, Folder, ActionProviderBase):
                 # This action requires no extra permissions.
                 verified = 1
             else:
+                # startswith() is used so that we can have several
+                # different categories that are checked in the object or
+                # folder context.
                 if (object is not None and
                     (category.startswith('object') or
                      category.startswith('workflow'))):
@@ -269,9 +245,7 @@ class ActionsTool(UniqueObject, Folder, ActionProviderBase):
     #
     #   Helper methods
     #
-    security.declarePrivate( '_listActions' )
-    def _listActions( self, append, object, info, ec ):
-
+    def _listActions(self,append,object,info,ec):
         a = object.listActions(info)
         if a and type(a[0]) is not type({}):
             for ai in a:
@@ -280,5 +254,6 @@ class ActionsTool(UniqueObject, Folder, ActionProviderBase):
         else:
             for i in a:
                 append(i)
+        
 
 InitializeClass(ActionsTool)
