@@ -12,7 +12,7 @@
 ##############################################################################
 """ Cookie Crumbler: Enable cookies for non-cookie user folders.
 
-$Id: CookieCrumbler.py,v 1.12.36.5 2003/04/28 21:12:43 shane Exp $
+$Id: CookieCrumbler.py,v 1.18.10.5 2004/04/23 21:11:33 sidnei Exp $
 """
 
 from base64 import encodestring
@@ -22,7 +22,8 @@ from utils import SimpleItemWithProperties
 from AccessControl import ClassSecurityInfo
 from ZPublisher import BeforeTraverse
 import Globals
-import CMFCorePermissions
+from CMFCorePermissions import ModifyCookieCrumblers
+from CMFCorePermissions import ViewManagementScreens
 from Globals import HTMLFile
 from zLOG import LOG, ERROR
 import sys
@@ -35,6 +36,12 @@ ATTEMPT_NONE = 0       # No attempt at authentication
 ATTEMPT_LOGIN = 1      # Attempt to log in
 ATTEMPT_RESUME = 2     # Attempt to resume session
 
+try:
+    from zExceptions import Redirect
+except ImportError:
+    # Pre Zope 2.7
+    Redirect = 'Redirect'
+
 
 class CookieCrumbler (SimpleItemWithProperties):
     '''
@@ -44,11 +51,9 @@ class CookieCrumbler (SimpleItemWithProperties):
     meta_type = 'Cookie Crumbler'
 
     security = ClassSecurityInfo()
-    security.declareProtected(CMFCorePermissions.ModifyCookieCrumblers,
-                              'manage_editProperties',
-                              'manage_changeProperties')
-    security.declareProtected(CMFCorePermissions.ViewManagementScreens,
-                              'manage_propertiesForm')
+    security.declareProtected(ModifyCookieCrumblers, 'manage_editProperties')
+    security.declareProtected(ModifyCookieCrumblers, 'manage_changeProperties')
+    security.declareProtected(ViewManagementScreens, 'manage_propertiesForm')
 
 
     _properties = ({'id':'auth_cookie', 'type': 'string', 'mode':'w',
@@ -105,7 +110,8 @@ class CookieCrumbler (SimpleItemWithProperties):
         if req.__class__ is not HTTPRequest:
             return ATTEMPT_DISABLED
 
-        if not req[ 'REQUEST_METHOD' ] in ( 'HEAD', 'GET', 'PUT', 'POST' ):
+        if (req[ 'REQUEST_METHOD' ] not in ( 'HEAD', 'GET', 'PUT', 'POST' )
+            and not req.has_key(self.auth_cookie)):
             return ATTEMPT_DISABLED
 
         if req.environ.has_key( 'WEBDAV_SOURCE_PORT' ):
@@ -154,7 +160,8 @@ class CookieCrumbler (SimpleItemWithProperties):
         if attempt == ATTEMPT_DISABLED:
             return
         if not req.get('disable_cookie_login__', 0):
-            if attempt == ATTEMPT_LOGIN or attempt == ATTEMPT_NONE:
+            if attempt == ATTEMPT_LOGIN or attempt == ATTEMPT_NONE \
+                   or attempt == ATTEMPT_RESUME:
                 # Modify the "unauthorized" response.
                 req._hold(ResponseCleanup(resp))
                 resp.unauthorized = self.unauthorized
@@ -197,7 +204,7 @@ class CookieCrumbler (SimpleItemWithProperties):
         # Redirect if desired.
         url = self.getLoginURL()
         if url is not None:
-            raise 'Redirect', url
+            raise Redirect, url
         # Fall through to the standard unauthorized() call.
         resp.unauthorized()
 
