@@ -1,34 +1,44 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
 """ Basic portal discussion access tool.
 
-$Id: DiscussionTool.py,v 1.6.16.1 2002/08/01 19:07:55 tseaver Exp $
+$Id: DiscussionTool.py,v 1.11.10.2 2004/04/23 21:11:33 sidnei Exp $
 """
 
-from utils import UniqueObject, getToolByName
-from utils import getToolByName, _dtmldir
-import CMFCorePermissions
+from utils import _dtmldir
+from utils import getToolByName
+from utils import UniqueObject
+from CMFCorePermissions import ReplyToItem
+from CMFCorePermissions import View
+from CMFCorePermissions import AccessContentsInformation
+from CMFCorePermissions import ManagePortal
 from OFS.SimpleItem import SimpleItem
 from Globals import InitializeClass, DTMLFile
-import Acquisition
+from Acquisition import Implicit
 from AccessControl import ClassSecurityInfo
 
+from interfaces.Discussions import OldDiscussable as IOldDiscussable
+from interfaces.portal_discussion \
+        import oldstyle_portal_discussion as IOldstyleDiscussionTool
 
-class OldDiscussable(Acquisition.Implicit):
+
+class OldDiscussable(Implicit):
     """
         Adapter for PortalContent to implement "old-style" discussions.
     """
 
+    __implements__ = IOldDiscussable
+
     _isDiscussable = 1
 
     security = ClassSecurityInfo()
@@ -37,7 +47,7 @@ class OldDiscussable(Acquisition.Implicit):
     def __init__( self, content ):
         self.content = content
 
-    security.declareProtected(CMFCorePermissions.ReplyToItem, 'createReply')
+    security.declareProtected(ReplyToItem, 'createReply')
     def createReply(self, title, text, REQUEST, RESPONSE):
         """
             Create a reply in the proper place
@@ -58,9 +68,8 @@ class OldDiscussable(Acquisition.Implicit):
         if not hasattr(home, 'Correspondence'):
             home.manage_addPortalFolder('Correspondence')
         location = home.Correspondence
-        location.manage_permission(CMFCorePermissions.View, ['Anonymous'], 1)
-        location.manage_permission(
-           CMFCorePermissions.AccessContentsInformation, ['Anonymous'], 1)
+        location.manage_permission(View, ['Anonymous'], 1)
+        location.manage_permission(AccessContentsInformation, ['Anonymous'], 1)
 
         # Find an unused id in location
         id = int(DateTime().timeTime())
@@ -69,7 +78,7 @@ class OldDiscussable(Acquisition.Implicit):
 
         return location, `id`
 
-    security.declareProtected(CMFCorePermissions.View, 'getReplyResults')
+    security.declareProtected(View, 'getReplyResults')
     def getReplyResults(self):
         """
             Return the ZCatalog results that represent this object's replies.
@@ -81,7 +90,7 @@ class OldDiscussable(Acquisition.Implicit):
         return catalog.searchResults(in_reply_to=
                                       urllib.unquote('/'+self.absolute_url(1)))
 
-    security.declareProtected(CMFCorePermissions.View, 'getReplies')
+    security.declareProtected(View, 'getReplies')
     def getReplies(self):
         """
             Return a sequence of the DiscussionResponse objects which are
@@ -103,6 +112,9 @@ class OldDiscussable(Acquisition.Implicit):
 
 
 class DiscussionTool (UniqueObject, SimpleItem):
+
+    __implements__ = IOldstyleDiscussionTool
+
     id = 'portal_discussion'
     meta_type = 'Oldstyle CMF Discussion Tool'
     # This tool is used to find the discussion for a given content object.
@@ -116,8 +128,7 @@ class DiscussionTool (UniqueObject, SimpleItem):
     #
     #   ZMI methods
     #
-    security.declareProtected( CMFCorePermissions.ManagePortal
-                             , 'manage_overview' )
+    security.declareProtected(ManagePortal, 'manage_overview')
     manage_overview = DTMLFile( 'explainDiscussionTool', _dtmldir )
 
     #
