@@ -1,115 +1,119 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
-"""PortalFolder: CMF-enabled Folder objects.
-$Id: PortalFolder.py,v 1.27.2.1 2001/12/10 20:26:39 tseaver Exp $
+""" PortalFolder: CMF-enabled Folder objects.
+
+$Id: PortalFolder.py,v 1.45.4.9 2004/08/09 16:33:14 tseaver Exp $
 """
 
-__version__='$Revision: 1.27.2.1 $'[11:-2]
-
-ADD_FOLDERS_PERMISSION = 'Add portal folders'
-ADD_CONTENT_PERMISSION = 'Add portal content'
-
+import sys
 import Globals, re, base64, marshal, string
-import CMFCorePermissions
 
-from CMFCorePermissions import View, ManageProperties, ListFolderContents
-from CMFCorePermissions import AddPortalFolders, AddPortalContent
+from CMFCorePermissions import View
+from CMFCorePermissions import ManageProperties
+from CMFCorePermissions import ListFolderContents
+from CMFCorePermissions import AddPortalFolders
+from CMFCorePermissions import AddPortalContent
+from CMFCorePermissions import DeleteObjects
+from CMFCatalogAware import CMFCatalogAware
 from OFS.Folder import Folder
 from OFS.ObjectManager import REPLACEABLE
 from Globals import DTMLFile
-from AccessControl import getSecurityManager, ClassSecurityInfo
+from AccessControl import getSecurityManager, ClassSecurityInfo, Unauthorized
 from Acquisition import aq_parent, aq_inner, aq_base
 from DynamicType import DynamicType
 from utils import getToolByName, _checkPermission
 
-factory_type_information = ( { 'id'             : 'Folder'
-                             , 'meta_type'      : 'Portal Folder'
-                             , 'description'    : """\
-Use folders to put content in categories."""
-                             , 'icon'           : 'folder_icon.gif'
-                             , 'product'        : 'CMFCore'
-                             , 'factory'        : 'manage_addPortalFolder'
-                             , 'filter_content_types' : 0
-                             , 'immediate_view' : 'folder_edit_form'
-                             , 'actions'        :
-                                ( { 'id'            : 'view'
-                                  , 'name'          : 'View'
-                                  , 'action'        : ''
-                                  , 'permissions'   : (View,)
-                                  , 'category'      : 'folder'
-                                  }
-                                , { 'id'            : 'edit'
-                                  , 'name'          : 'Edit'
-                                  , 'action'        : 'folder_edit_form'
-                                  , 'permissions'   : (ManageProperties,)
-                                  , 'category'      : 'folder'
-                                  }
-                                , { 'id'            : 'localroles'
-                                  , 'name'          : 'Local Roles'
-                                  , 'action'        : 'folder_localrole_form'
-                                  , 'permissions'   : (ManageProperties,)
-                                  , 'category'      : 'folder'
-                                  }
-                                , { 'id'            : 'syndication'
-                                  , 'name'          : 'Syndication'
-                                  , 'action'        : 'synPropertiesForm'
-                                  , 'permissions'   : (ManageProperties,)
-                                  , 'category'      : 'folder'
-                                  }
-                                )
-                             }
-                           ,
-                           )
+try:
+    from zExceptions import BadRequest
+except ImportError:
+    BadRequest = 'BadRequest'
+
+factory_type_information = (
+  { 'id'             : 'Folder'
+  , 'meta_type'      : 'Portal Folder'
+  , 'description'    : """ Use folders to put content in categories."""
+  , 'icon'           : 'folder_icon.gif'
+  , 'product'        : 'CMFCore'
+  , 'factory'        : 'manage_addPortalFolder'
+  , 'filter_content_types' : 0
+  , 'immediate_view' : 'folder_edit_form'
+  , 'actions'        : ( { 'id'            : 'view'
+                         , 'name'          : 'View'
+                         , 'action': 'string:${object_url}'
+                         , 'permissions'   : (View,)
+                         , 'category'      : 'folder'
+                         }
+                       , { 'id'            : 'edit'
+                         , 'name'          : 'Edit'
+                         , 'action': 'string:${object_url}/folder_edit_form'
+                         , 'permissions'   : (ManageProperties,)
+                         , 'category'      : 'folder'
+                         }
+                       , { 'id'            : 'localroles'
+                         , 'name'          : 'Local Roles'
+                         , 'action':
+                                  'string:${object_url}/folder_localrole_form'
+                         , 'permissions'   : (ManageProperties,)
+                         , 'category'      : 'folder'
+                         }
+                       )
+  }
+,
+)
 
 
-class PortalFolder( Folder, DynamicType ):
+class PortalFolder(DynamicType, CMFCatalogAware, Folder):
     """
         Implements portal content management, but not UI details.
     """
     meta_type = 'Portal Folder'
     portal_type = 'Folder'
 
+    __implements__ = (DynamicType.__implements__, Folder.__implements__)
+
     security = ClassSecurityInfo()
 
     description = ''
 
+    manage_options = Folder.manage_options + \
+                     CMFCatalogAware.manage_options
+
     def __init__( self, id, title='' ):
         self.id = id
         self.title = title
 
-    security.declareProtected( CMFCorePermissions.ManageProperties
-                             , 'setTitle')
+    security.declareProtected(ManageProperties, 'setTitle')
     def setTitle( self, title ):
         """
             Edit the folder title.
         """
         self.title = title
 
-    security.declareProtected( CMFCorePermissions.ManageProperties
-                             , 'setDescription')
+    security.declareProtected(ManageProperties, 'setDescription')
     def setDescription( self, description ):
         """
             Edit the folder description.
         """
         self.description = description
 
-    security.declareProtected(CMFCorePermissions.ManageProperties, 'edit')
+    security.declareProtected(ManageProperties, 'edit')
     def edit(self, title='', description=''):
         """
         Edit the folder title (and possibly other attributes later)
         """
         self.setTitle( title )
         self.setDescription( description )
+        self.reindexObject()
 
     security.declarePublic('allowedContentTypes')
     def allowedContentTypes( self ):
@@ -122,8 +126,8 @@ class PortalFolder( Folder, DynamicType ):
         myType = portal_types.getTypeInfo(self)
 
         if myType is not None:
-            for contentType in portal_types.listTypeInfo():
-                if myType.allowType( contentType.Type() ):
+            for contentType in portal_types.listTypeInfo(self):
+                if myType.allowType( contentType.getId() ):
                     result.append( contentType )
         else:
             result = portal_types.listTypeInfo()
@@ -136,7 +140,7 @@ class PortalFolder( Folder, DynamicType ):
     def manage_addPortalFolder(self, id, title='', REQUEST=None):
         """Add a new PortalFolder object with id *id*.
         """
-        ob=PortalFolder(id, title)
+        ob = PortalFolder(id, title)
         self._setObject(id, ob)
         if REQUEST is not None:
             return self.folder_contents( # XXX: ick!
@@ -162,12 +166,33 @@ class PortalFolder( Folder, DynamicType ):
                 new_spec.append(meta_type)
         return new_spec or types
     
-    def _filteredItems( self, ids, filter ):
+    def _filteredItems( self, ids, filt ):
         """
             Apply filter, a mapping, to child objects indicated by 'ids',
             returning a sequence of ( id, obj ) tuples.
         """
-        query = apply( ContentFilter, (), filter )
+        # Restrict allowed content types
+        if filt is None:
+            filt = {}
+        else:
+            # We'll modify it, work on a copy.
+            filt = filt.copy()
+        pt = filt.get('portal_type', [])
+        if type(pt) is type(''):
+            pt = [pt]
+        types_tool = getToolByName(self, 'portal_types')
+        allowed_types = types_tool.listContentTypes()
+        if not pt:
+            pt = allowed_types
+        else:
+            pt = [t for t in pt if t in allowed_types]
+        if not pt:
+            # After filtering, no types remain, so nothing should be
+            # returned.
+            return []
+        filt['portal_type'] = pt
+
+        query = apply( ContentFilter, (), filt )
         result = []
         append = result.append
         get = self._getOb
@@ -189,10 +214,6 @@ class PortalFolder( Folder, DynamicType ):
         """
         spec = self._morphSpec( spec )
         ids = self.objectIds( spec )
-
-        if not filter:
-            return ids
-
         return map( lambda item: item[0],
                     self._filteredItems( ids, filter ) )
 
@@ -203,29 +224,27 @@ class PortalFolder( Folder, DynamicType ):
             PortalFolders and PortalContent-derivatives to show through.
         """
         spec = self._morphSpec( spec )
-        if not filter:
-            return self.objectValues( spec )
-
         ids = self.objectIds( spec )
         return map( lambda item: item[1],
                     self._filteredItems( ids, filter ) )
 
-    security.declareProtected( ListFolderContents
-                             , 'listFolderContents' )
-    def listFolderContents( self, spec=None, contentFilter=None ): # XXX
+    security.declareProtected(ListFolderContents, 'listFolderContents')
+    def listFolderContents( self, spec=None, contentFilter=None ):
         """
             Hook around 'contentValues' to let 'folder_contents'
             be protected.  Duplicating skip_unauthorized behavior of dtml-in.
         """
-        items = self.contentValues(filter=contentFilter)
+        items = self.contentValues(spec=spec, filter=contentFilter)
         l = []
         for obj in items:
             id = obj.getId()
             v = obj
-            try: 
+            # validate() can either raise Unauthorized or return 0 to
+            # mean unauthorized.
+            try:
                 if getSecurityManager().validate(self, self, id, v):
                     l.append(obj)
-            except "Unauthorized":
+            except Unauthorized:
                 pass
         return l
 
@@ -237,9 +256,6 @@ class PortalFolder( Folder, DynamicType ):
             PortalFolders and PortalContent-derivatives to show through.
         """
         spec = self._morphSpec( spec )
-        if not filter:
-            return self.objectItems( spec )
-
         ids = self.objectIds( spec )
         return self._filteredItems( ids, filter )
 
@@ -262,10 +278,10 @@ class PortalFolder( Folder, DynamicType ):
         """
              Implement dublin core type
         """
-        portal_types = getToolByName(self, 'portal_types')
-        ti = portal_types.getTypeInfo(self)
-        if ti is not None:
-            return ti.Type()
+        if hasattr(aq_base(self), 'getTypeInfo'):
+            ti = self.getTypeInfo()
+            if ti is not None:
+                return ti.Title()
         return self.meta_type
 
     security.declarePublic('encodeFolderFilter')
@@ -297,6 +313,18 @@ class PortalFolder( Folder, DynamicType ):
         """
         return None
 
+    # Ensure pure PortalFolders don't get cataloged.
+    # XXX We may want to revisit this.
+
+    def indexObject(self):
+        pass
+
+    def unindexObject(self):
+        pass
+
+    def reindexObject(self, idxs=[]):
+        pass
+
     def PUT_factory( self, name, typ, body ):
         """
             Dispatcher for PUT requests to non-existent IDs.  Returns
@@ -330,11 +358,32 @@ class PortalFolder( Folder, DynamicType ):
         Invokes the portal_types tool.
         '''
         pt = getToolByName( self, 'portal_types' )
+        myType = pt.getTypeInfo(self)
+
+        if myType is not None:
+            if not myType.allowType( type_name ):
+                raise ValueError, 'Disallowed subobject type: %s' % type_name
+
         apply( pt.constructContent
              , (type_name, self, id, RESPONSE) + args
              , kw
              )
 
+    security.declareProtected(AddPortalContent, 'checkIdAvailable')
+    def checkIdAvailable(self, id):
+        try:
+            self._checkId(id)
+        except BadRequest:
+            return 0
+        except:
+            # Zope < 2.7
+            e, v, tb = sys.exc_info(); del tb
+            if str(e) == 'Bad Request':
+                return 0
+            raise  # Some other exception.
+        else:
+            return 1
+
     def MKCOL_handler(self,id,REQUEST=None,RESPONSE=None):
         """
             Handle WebDAV MKCOL.
@@ -364,64 +413,100 @@ class PortalFolder( Folder, DynamicType ):
         # This assists the version in OFS.CopySupport.
         # It enables the clipboard to function correctly
         # with objects created by a multi-factory.
-        if (hasattr(object, '__factory_meta_type__') and
-            hasattr(self, 'all_meta_types')):
-            mt = object.__factory_meta_type__
+        securityChecksDone = 0
+
+        sm = getSecurityManager()
+        parent = aq_parent(aq_inner(object))
+        object_id = object.getId()
+        mt = getattr(object, '__factory_meta_type__', None)
+        meta_types = getattr(self, 'all_meta_types', None)
+
+        if mt is not None and meta_types is not None:
+
             method_name=None
             permission_name = None
-            meta_types = self.all_meta_types
-            if callable(meta_types): meta_types = meta_types()
+
+            if callable(meta_types):
+                meta_types = meta_types()
+
             for d in meta_types:
+
                 if d['name']==mt:
+
                     method_name=d['action']
                     permission_name = d.get('permission', None)
                     break
 
             if permission_name is not None:
-                if _checkPermission(permission_name,self):
-                    if not validate_src:
-                        # We don't want to check the object on the clipboard
-                        return
-                    try: parent = aq_parent(aq_inner(object))
-                    except: parent = None
-                    if getSecurityManager().validate(None, parent,
-                                                     None, object):
-                        # validation succeeded
-                        return
-                    raise 'Unauthorized', object.getId()
-                else:
-                    raise 'Unauthorized', permission_name
+
+                if not sm.checkPermission(permission_name,self):
+                    raise Unauthorized, method_name
+
+                if validate_src:
+                
+                    if not sm.validate(None, parent, None, object):
+                        raise Unauthorized, object_id
+
+                if validate_src > 1:
+                    if not sm.checkPermission(DeleteObjects, parent):
+                        raise Unauthorized
+
+                # validation succeeded
+                securityChecksDone = 1
             #
             # Old validation for objects that may not have registered 
             # themselves in the proper fashion.
             #
             elif method_name is not None:
-                meth=self.unrestrictedTraverse(method_name)
-                if hasattr(meth, 'im_self'):
-                    parent = meth.im_self
-                else:
-                    try:    parent = aq_parent(aq_inner(meth))
-                    except: parent = None
-                if getSecurityManager().validate(None, parent, None, meth):
-                    # Ensure the user is allowed to access the object on the
-                    # clipboard.
-                    if not validate_src:
-                        return
-                    try: parent = aq_parent(aq_inner(object))
-                    except: parent = None
-                    if getSecurityManager().validate(None, parent,
-                                                     None, object):
-                        return
-                    id = object.getId()
-                    raise 'Unauthorized', id
-                else:
-                    raise 'Unauthorized', method_name
-        PortalFolder.inheritedAttribute(
-            '_verifyObjectPaste')(self, object, validate_src)
+
+                meth = self.unrestrictedTraverse(method_name)
+
+                factory = getattr(meth, 'im_self', None)
+
+                if factory is None:
+                    factory = aq_parent(aq_inner(meth))
+
+                if not sm.validate(None, factory, None, meth):
+                    raise Unauthorized, method_name
+
+                # Ensure the user is allowed to access the object on the
+                # clipboard.
+                if validate_src:
+
+                    if not sm.validate(None, parent, None, object):
+                        raise Unauthorized, object_id
+
+                if validate_src > 1: # moving
+                    if not sm.checkPermission(DeleteObjects, parent):
+                        raise Unauthorized
+
+                securityChecksDone = 1
+
+        # Call OFS' _verifyObjectPaste if necessary
+        if not securityChecksDone:
+
+            PortalFolder.inheritedAttribute(
+                '_verifyObjectPaste')(self, object, validate_src)
+
+        # Finally, check allowed content types
+        content_type = getattr(aq_base(object), '_getPortalTypeName', None)
+        if content_type is not None:
+
+            content_type = content_type()
+
+            if content_type is not None:
+
+                pt = getToolByName(self, 'portal_types')
+                myType = pt.getTypeInfo(self)
+
+                if myType is not None and not myType.allowType(content_type):
+                    raise ValueError(
+                          "Cannot paste subobject type '%s'." % content_type )
 
     security.setPermissionDefault(AddPortalContent, ('Owner','Manager'))
     security.setPermissionDefault(AddPortalFolders, ('Owner','Manager'))
 
+    security.declareProtected(AddPortalFolders, 'manage_addFolder') 
     def manage_addFolder( self
                         , id
                         , title=''
@@ -436,7 +521,7 @@ class PortalFolder( Folder, DynamicType ):
         """
         try:
             action = self.getTypeInfo().getActionById( 'mkdir' )
-        except TypeError:
+        except ValueError:
             self.invokeFactory( type_name='Folder', id=id )
         else:
             # call it
@@ -472,6 +557,7 @@ class ContentFilter:
                 , modified=MARKER
                 , modified_usage='range:min'
                 , Type=MARKER
+                , portal_type=MARKER
                 , **Ignored
                 ):
 
@@ -479,7 +565,6 @@ class ContentFilter:
         self.description = []
 
         if Title is not self.MARKER: 
-            self.filterTitle = Title
             self.predicates.append( lambda x, pat=re.compile( Title ):
                                       pat.search( x.Title() ) )
             self.description.append( 'Title: %s' % Title )
@@ -528,6 +613,14 @@ class ContentFilter:
             self.description.append( 'Type: %s'
                                    % string.join( Type, ', ' ) )
 
+        if portal_type and portal_type is not self.MARKER:
+            if type(portal_type) is type(''):
+                portal_type = [portal_type]
+            self.predicates.append(lambda x, pt=portal_type:
+                                   x.getPortalTypeName() in pt)
+            self.description.append('Portal Type: %s'
+                                    % string.join(portal_type, ', '))
+
     def hasSubject( self, obj ):
         """
         Converts Subject string into a List for content filter view.
@@ -544,9 +637,10 @@ class ContentFilter:
             try:
                 if not predicate( content ):
                     return 0
-            except: # predicates are *not* allowed to throw exceptions
+            except (AttributeError, KeyError, IndexError, ValueError):
+                # predicates are *not* allowed to throw exceptions
                 return 0
-        
+
         return 1
 
     def __str__( self ):
