@@ -1,57 +1,68 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
 """ Type registration tool.
 
-$Id: TypesTool.py,v 1.37.4.7 2002/08/05 21:20:43 shane Exp $
+$Id: TypesTool.py,v 1.53.2.5 2004/04/23 21:11:33 sidnei Exp $
 """
-
-import OFS
-from Globals import InitializeClass, DTMLFile
-from utils import UniqueObject, SimpleItemWithProperties, tuplize
-from utils import _dtmldir, _checkPermission, cookString, getToolByName
-import string
-from AccessControl import getSecurityManager, ClassSecurityInfo, Unauthorized
-from Acquisition import aq_base
-import Products, CMFCorePermissions
-from ActionProviderBase import ActionProviderBase
-from ActionInformation import ActionInformation
-from Expression import Expression
-from zLOG import LOG, WARNING, ERROR
 import sys
 
-from CMFCorePermissions import View, ManagePortal, AccessContentsInformation
+from Globals import DTMLFile
+from Globals import InitializeClass
+from AccessControl import ClassSecurityInfo
+from AccessControl import getSecurityManager
+from AccessControl import Unauthorized
+from Acquisition import aq_base
+from Acquisition import aq_get
+from zLOG import LOG, WARNING, ERROR
+from OFS.Folder import Folder
+import Products
+
+from interfaces.portal_types import ContentTypeInformation as ITypeInformation
+from interfaces.portal_types import portal_types as ITypesTool
+
+from ActionProviderBase import ActionProviderBase
+
+from CMFCorePermissions import View
+from CMFCorePermissions import ManagePortal
+from CMFCorePermissions import AccessContentsInformation
+
+from utils import UniqueObject
+from utils import SimpleItemWithProperties
+from utils import _dtmldir
+from utils import _checkPermission
+from utils import cookString
+from utils import getActionContext
 
 _marker = []  # Create a new marker.
 
-class TypeInformation (SimpleItemWithProperties):
+class TypeInformation (SimpleItemWithProperties, ActionProviderBase):
     """
     Base class for information about a content type.
     """
+
     _isTypeInformation = 1
 
-    manage_options = (SimpleItemWithProperties.manage_options[:1] +
-                      ({'label':'Actions',
-                        'action':'manage_editActionsForm'},) +
-                      SimpleItemWithProperties.manage_options[1:])
+    manage_options = ( SimpleItemWithProperties.manage_options[:1]
+                     + ActionProviderBase.manage_options
+                     + SimpleItemWithProperties.manage_options[1:]
+                     )
 
 
     security = ClassSecurityInfo()
-    security.declareProtected(CMFCorePermissions.ManagePortal,
-                              'manage_editProperties',
-                              'manage_changeProperties',
-                              'manage_propertiesForm',
-                              )
 
+    security.declareProtected(ManagePortal, 'manage_editProperties')
+    security.declareProtected(ManagePortal, 'manage_changeProperties')
+    security.declareProtected(ManagePortal, 'manage_propertiesForm')
 
     _basic_properties = (
         {'id':'title', 'type': 'string', 'mode':'w',
@@ -91,31 +102,35 @@ class TypeInformation (SimpleItemWithProperties):
     allowed_content_types = ()
     allow_discussion = 0
     global_allow = 1
-    _actions = ()
 
     def __init__(self, id, **kw):
+
         self.id = id
+
+        kw = kw.copy()  # Get a modifiable dict.
+
         if kw:
-            kw = kw.copy()  # Get a modifiable dict.
+
             if (not kw.has_key('content_meta_type')
                 and kw.has_key('meta_type')):
                 kw['content_meta_type'] = kw['meta_type']
+
             if (not kw.has_key('content_icon')
                 and kw.has_key('icon')):
                 kw['content_icon'] = kw['icon']
+
             apply(self.manage_changeProperties, (), kw)
-            if kw.has_key('actions'):
-                aa = kw['actions']
-                actions = []
-                for action in aa:
-                    action = action.copy()
-                    # Some backward compatibility stuff.
-                    if not action.has_key('id'):
-                        action['id'] = cookString(action['name'])
-                    if not action.has_key('category'):
-                        action['category'] = 'object'
-                    actions.append(action)
-                self._actions = tuple(actions)
+
+        actions = kw.get( 'actions', () )
+        # make sure we have a copy
+        _actions = []
+        for action in actions:
+            _actions.append( action.copy() )
+        actions = tuple(_actions)
+        # We don't know if actions need conversion, so we always add oldstyle
+        # _actions and convert them.
+        self._actions = actions
+        self._convertActions()
 
     #
     #   Accessors
@@ -172,6 +187,10 @@ class TypeInformation (SimpleItemWithProperties):
             if ti is None or ti.globalAllow():
                 return 1
 
+        #If a type is enabled to filter and no content_types are allowed
+        if not self.allowed_content_types:
+            return 0
+
         if contentType in self.allowed_content_types:
             return 1
 
@@ -193,14 +212,6 @@ class TypeInformation (SimpleItemWithProperties):
         """
         return self.allow_discussion
 
-    security.declarePrivate('getActions')
-    def getActions(self):
-        """
-        Returns the customizable user actions.
-        """
-        # Private because this returns the actual structure.
-        return self._actions
-
     security.declarePublic('globalAllow')
     def globalAllow(self):
         """
@@ -208,203 +219,74 @@ class TypeInformation (SimpleItemWithProperties):
         """
         return self.global_allow
 
+    security.declarePublic('listActions')
+    def listActions( self, info=None ):
+
+        """ Return a sequence of the action info objects for this type.
+        """
+        if self._actions and type( self._actions[0] ) == type( {} ):
+            self._convertActions()
+
+        return self._actions or ()
+
     security.declarePublic('getActionById')
     def getActionById( self, id, default=_marker ):
         """
             Return the URL of the action whose ID is id.
         """
-        for action in self.getActions():
+        context = getActionContext( self )
+        for action in self.listActions():
 
-            if action.has_key('id'):
-                if action['id'] == id:
-                    return action['action']
+            __traceback_info__ = (self.getId(), action)
+
+            if action.getId() == id:
+                target = action.action(context).strip()
+                if target.startswith('/'):
+                    target = target[1:]
+                return target
             else:
                 # Temporary backward compatibility.
-                if string.lower(action['name']) == id:
-                    return action['action']
+                if action.Title().lower() == id:
+                    target = action.action(context).strip()
+                    if target.startswith('/'):
+                        target = target[1:]
+                    return target
 
         if default is _marker:
-            raise TypeError, ( 'No action "%s" for type "%s"'
-                             % ( id, self.getId() )
-                             )
+            raise ValueError, ('No action "%s" for type "%s"'
+                               % (id, self.getId()))
         else:
             return default
 
-    #
-    #  Action editing interface
-    #
-    _actions_form = DTMLFile( 'editActions', _dtmldir )
-    
-    security.declareProtected(ManagePortal, 'manage_editActionsForm')
-    def manage_editActionsForm(self, REQUEST, manage_tabs_message=None):
+    security.declarePrivate( '_convertActions' )
+    def _convertActions( self ):
+        """ Upgrade dictionary-based actions.
         """
-        Shows the 'Actions' management tab.
-        """
-        actions = []
-        for a in self.getActions():
-            a = a.copy()
-            p = a['permissions']
-            if p:
-                a['permission'] = p[0]
-            else:
-                a['permission'] = ''
-            if not a.has_key('category'):
-                a['category'] = 'object'
-            if not a.has_key('id'):
-                a['id'] = cookString(a['name'])
-            if not a.has_key( 'visible' ):
-                a['visible'] = 1
-            actions.append(a)
-        # possible_permissions is in AccessControl.Role.RoleManager.
-        pp = self.possible_permissions()
-        return self._actions_form(self, REQUEST,
-                                  actions=actions,
-                                  possible_permissions=pp,
-                                  management_view='Actions',
-                                  manage_tabs_message=manage_tabs_message)
+        aa, self._actions = self._actions, ()
 
-    security.declareProtected(ManagePortal, 'addAction')
-    def addAction( self
-                 , id
-                 , name
-                 , action
-                 , permission
-                 , category
-                 , visible=1
-                 , REQUEST=None
-                 ):
-        """
-        Adds an action to the list.
-        """
-        if not name:
-            raise ValueError('A name is required.')
+        for action in aa:
 
-        new_actions = self._cloneActions()
+            # Some backward compatibility stuff.
+            if not action.has_key('id'):
+                action['id'] = cookString(action['name'])
 
-        new_actions.append( { 'id'          : str(id)
-                            , 'name'        : str(name)
-                            , 'action'      : str(action)
-                            , 'permissions' : (str(permission),)
-                            , 'category'    : str(category)
-                            , 'visible'     : int(visible) 
-                            } )
+            if not action.has_key('name'):
+                action['name'] = action['id'].capitalize()
 
-        self._actions = tuple( new_actions )
+            # historically, action['action'] is simple string
+            actiontext = action.get('action').strip() or 'string:${object_url}'
+            if actiontext[:7] not in ('python:', 'string:'):
+                actiontext = 'string:${object_url}/%s' % actiontext
 
-        if REQUEST is not None:
-            return self.manage_editActionsForm(
-                REQUEST, manage_tabs_message='Added.')
-    
-    security.declareProtected(ManagePortal, 'changeActions')
-    def changeActions(self, properties=None, REQUEST=None):
-        """
-        Changes the _actions.
-        """
-        if properties is None:
-            properties = REQUEST
-        actions = []
-        for idx in range(len(self._actions)):
-            s_idx = str(idx)
-            action = self._actions[idx].copy()
-            action.update( {
-                    'id': str(properties.get('id_' + s_idx, '')),
-                    'name': str(properties.get('name_' + s_idx, '')),
-                    'action': str(properties.get('action_' + s_idx, '')),
-                    'permissions':
-                    (properties.get('permission_' + s_idx, ()),),
-                    'category': str(properties.get('category_' + s_idx, '')),
-                    'visible': not not properties.get('visible_' + s_idx, 0),
-                    } )
-            if not action['name']:
-                raise ValueError('A name is required.')
-            actions.append( action )
-        self._actions = tuple( actions )
-        if REQUEST is not None:
-            return self.manage_editActionsForm(REQUEST, manage_tabs_message=
-                                               'Actions changed.')
-
-    security.declareProtected(ManagePortal, 'deleteActions')
-    def deleteActions(self, selections=(), REQUEST=None):
-        """
-        Deletes actions.
-        """
-        sels = list(map(int, selections))  # Convert to a list of integers.
-        sels.sort()
-        sels.reverse()
-
-        new_actions = self._cloneActions()
-
-        for idx in sels:
-            del new_actions[idx]
-
-        self._actions = tuple(new_actions)
-
-        if REQUEST is not None:
-            return self.manage_editActionsForm(
-                REQUEST, manage_tabs_message=(
-                'Deleted %d action(s).' % len(sels)))
-
-    security.declareProtected(ManagePortal, 'moveUpActions')
-    def moveUpActions(self, selections=(), REQUEST=None):
-        """
-        Moves the specified actions up one slot.
-        """
-        sels = list(map(int, selections))  # Convert to a list of integers.
-        sels.sort()
-
-        new_actions = self._cloneActions()
-
-        for idx in sels:
-            idx2 = idx - 1
-            if idx2 < 0:
-                # Wrap to the bottom.
-                idx2 = len(new_actions) - 1
-            # Swap.
-            a = new_actions[idx2]
-            new_actions[idx2] = new_actions[idx]
-            new_actions[idx] = a
-
-        self._actions = tuple(new_actions)
-
-        if REQUEST is not None:
-            return self.manage_editActionsForm(
-                REQUEST, manage_tabs_message=(
-                'Moved up %d action(s).' % len(sels)))
-
-    security.declareProtected(ManagePortal, 'moveDownActions')
-    def moveDownActions(self, selections=(), REQUEST=None):
-        """
-        Moves the specified actions down one slot.
-        """
-        sels = list(map(int, selections))  # Convert to a list of integers.
-        sels.sort()
-        sels.reverse()
-
-        new_actions = self._cloneActions()
-
-        for idx in sels:
-            idx2 = idx + 1
-            if idx2 >= len(new_actions):
-                # Wrap to the top.
-                idx2 = 0
-            # Swap.
-            a = new_actions[idx2]
-            new_actions[idx2] = new_actions[idx]
-            new_actions[idx] = a
-
-        self._actions = tuple(new_actions)
-
-        if REQUEST is not None:
-            return self.manage_editActionsForm(
-                REQUEST, manage_tabs_message=(
-                'Moved down %d action(s).' % len(sels)))
-
-    security.declarePrivate( '_cloneActions' )
-    def _cloneActions( self ):
-        """
-            Return a "deep copy" of our list of actions.
-        """
-        return map( lambda x: x.copy(), list( self._actions ) )
+            self.addAction(
+                  id=action['id']
+                , name=action['name']
+                , action=actiontext
+                , condition=action.get('condition')
+                , permission=action.get( 'permissions', () )
+                , category=action.get('category', 'object')
+                , visible=action.get('visible', 1)
+                )
 
     security.declarePrivate('_finishConstruction')
     def _finishConstruction(self, ob):
@@ -428,6 +310,9 @@ class FactoryTypeInformation (TypeInformation):
     """
     Portal content factory.
     """
+
+    __implements__ = ITypeInformation
+
     meta_type = 'Factory-based Type Information'
     security = ClassSecurityInfo()
 
@@ -479,7 +364,7 @@ class FactoryTypeInformation (TypeInformation):
         return default
 
     security.declarePublic('isConstructionAllowed')
-    def isConstructionAllowed ( self, container ):
+    def isConstructionAllowed( self, container ):
         """
         a. Does the factory method exist?
 
@@ -522,6 +407,9 @@ class ScriptableTypeInformation( TypeInformation ):
     """
     Invokes a script rather than a factory to create the content.
     """
+
+    __implements__ = ITypeInformation
+
     meta_type = 'Scriptable Type Information'
     security = ClassSecurityInfo()
 
@@ -559,6 +447,10 @@ class ScriptableTypeInformation( TypeInformation ):
             raise Unauthorized
 
         constructor = self.restrictedTraverse( self.constructor_path )
+        # make sure ownership is explicit before switching the context
+        if not hasattr( aq_base(constructor), '_owner' ):
+            constructor._owner = aq_get(constructor, '_owner')
+
         #   Rewrap to get into container's context.
         constructor = aq_base(constructor).__of__( container )
 
@@ -595,17 +487,19 @@ allowedTypes = [
     ]
 
 
-class TypesTool( UniqueObject, OFS.Folder.Folder, ActionProviderBase ):
+class TypesTool(UniqueObject, Folder, ActionProviderBase):
     """
         Provides a configurable registry of portal content types.
     """
+
+    __implements__ = (ITypesTool, ActionProviderBase.__implements__)
+
     id = 'portal_types'
     meta_type = 'CMF Types Tool'
-    _actions = []
 
     security = ClassSecurityInfo()
 
-    manage_options = ( OFS.Folder.Folder.manage_options +
+    manage_options = ( Folder.manage_options +
                       ActionProviderBase.manage_options +
                       ({ 'label' : 'Overview', 'action' : 'manage_overview' }
                      , 
@@ -614,18 +508,9 @@ class TypesTool( UniqueObject, OFS.Folder.Folder, ActionProviderBase ):
     #
     #   ZMI methods
     #
-    security.declareProtected( CMFCorePermissions.ManagePortal
-                             , 'manage_overview' )
+    security.declareProtected(ManagePortal, 'manage_overview')
     manage_overview = DTMLFile( 'explainTypesTool', _dtmldir )
 
-    security.declarePrivate('listActions')
-    def listActions(self, info=None):
-        """
-        Return a list of action information instances
-        for actions provided via tool
-        """
-        return self._actions
-
     def all_meta_types(self):
         """Adds TypesTool-specific meta types."""
         all = TypesTool.inheritedAttribute('all_meta_types')(self)
@@ -828,4 +713,20 @@ class TypesTool( UniqueObject, OFS.Folder.Folder, ActionProviderBase ):
                                       , info.immediate_view )
             RESPONSE.redirect( immediate_url )
 
+    security.declarePrivate( 'listActions' )
+    def listActions( self, info=None ):
+        """
+            List type-related actions.
+        """
+        actions = list( self._actions )
+
+        if info is not None:
+
+            type_info = self.getTypeInfo( info.content )
+
+            if type_info is not None:
+                actions.extend( type_info.listActions( info ) )
+
+        return actions
+
 InitializeClass( TypesTool )
