@@ -1,25 +1,26 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
 """ Portal services base objects
 
-$Id: __init__.py,v 1.15.8.4 2002/11/21 17:56:18 mj Exp $
+$Id: __init__.py,v 1.23.10.2 2004/04/23 21:11:33 sidnei Exp $
 """
 
 import PortalObject, PortalContent, PortalFolder
 import MembershipTool, WorkflowTool, CatalogTool, DiscussionTool
 import ActionsTool, UndoTool, RegistrationTool, SkinsTool
 import MemberDataTool, TypesTool
-import DirectoryView, FSImage, FSPropertiesObject
+import URLTool
+import DirectoryView, FSImage, FSFile, FSPropertiesObject
 import FSDTMLMethod, FSPythonScript, FSSTXMethod
 import FSZSQLMethod
 import CookieCrumbler
@@ -57,6 +58,7 @@ tools = (
     SkinsTool.SkinsTool,
     MemberDataTool.MemberDataTool,
     TypesTool.TypesTool,
+    URLTool.URLTool,
     )
 
 
@@ -115,6 +117,8 @@ def initialize(context):
                        'images/fspy.gif', globals())
     utils.registerIcon(FSImage.FSImage,
                        'images/fsimage.gif', globals())
+    utils.registerIcon(FSFile.FSFile,
+                       'images/fsfile.gif', globals())
     utils.registerIcon(FSPropertiesObject.FSPropertiesObject,
                        'images/fsprops.gif', globals())
     utils.registerIcon(FSZSQLMethod.FSZSQLMethod,
