@@ -10,12 +10,19 @@
 # FOR A PARTICULAR PURPOSE
 # 
 ##############################################################################
-"""\
-Declare interface for synContentValues 
-"""
-import Interface
+""" Syndicatable interface.
 
-class Syndicatable(Interface.Base):
+$Id: Syndicatable.py,v 1.3.14.2 2004/04/23 21:11:34 sidnei Exp $
+"""
+
+try:
+    from Interface import Interface
+except ImportError:
+    # for Zope versions before 2.6.0
+    from Interface import Base as Interface
+
+
+class Syndicatable(Interface):
     """\
     Returns back a list of objects which implements the DublinCore.
     """
