@@ -1,55 +1,65 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
+""" Discussion item portal type.
 
-import urllib, string
-from Globals import HTMLFile, Persistent, PersistentMapping, InitializeClass
+$Id: DiscussionItem.py,v 1.33.4.3 2004/08/07 12:59:42 jens Exp $
+"""
+
+from Globals import Persistent, PersistentMapping, InitializeClass
 from AccessControl import ClassSecurityInfo
 from Acquisition import Implicit, aq_base, aq_inner, aq_parent
 from OFS.Traversable import Traversable
 from DateTime import DateTime
 
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore.CMFCorePermissions import View
+from Products.CMFCore.CMFCorePermissions import AccessContentsInformation
+from Products.CMFCore.CMFCorePermissions import ReplyToItem
+from Products.CMFCore.CMFCorePermissions import ManagePortal
 from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.PortalContent import PortalContent
 
 from Document import Document
 from DublinCore import DefaultDublinCoreImpl
 
+from Products.CMFCore.interfaces.Discussions import DiscussionResponse
+from Products.CMFCore.interfaces.Discussions import Discussable
 
-factory_type_information = ( { 'id'             : 'Discussion Item'
-                             , 'meta_type'      : 'Discussion Item'
-                             , 'description'    : """\
+
+factory_type_information = (
+  { 'id'             : 'Discussion Item'
+  , 'meta_type'      : 'Discussion Item'
+  , 'description'    : """\
 Discussion Items are documents which reply to other content.
-They should *not* be addable through the standard 'folder_factories'
-interface."""
-                             , 'icon'           : 'discussionitem_icon.gif'
-                             , 'product'        : '' # leave blank to suppress
-                             , 'factory'        : ''
-                             , 'immediate_view' : ''
-                             , 'actions'        :
-                                ( { 'id'            : 'view'
-                                  , 'name'          : 'View'
-                                  , 'action'        : 'discussionitem_view'
-                                  , 'permissions'   : (
-                                      CMFCorePermissions.View, )
-                                  }
-                                ,
-                                )
-                             }
-                           ,
-                           )
+They should *not* be addable through the standard 'folder_factories' interface.
+"""
+  , 'icon'           : 'discussionitem_icon.gif'
+  , 'product'        : '' # leave blank to suppress
+  , 'factory'        : ''
+  , 'immediate_view' : ''
+  , 'actions'        : ( { 'id'            : 'view'
+                         , 'name'          : 'View'
+                         , 'action': 'string:${object_url}/discussionitem_view'
+                         , 'permissions'   : (View,)
+                         }
+                       ,
+                       )
+  }
+,
+)
 
 
+from utils import scrubHTML
+
 def addDiscussionItem(self, id, title, description, text_format, text,
                       reply_to, RESPONSE=None):
     """
@@ -63,7 +73,7 @@ def addDiscussionItem(self, id, title, description, text_format, text,
     """
 
     if not description: description = title
-        
+    text = scrubHTML(text)
     item = DiscussionItem( id )
     item.title = title
     item.description = description
@@ -77,7 +87,7 @@ def addDiscussionItem(self, id, title, description, text_format, text,
     if RESPONSE is not None:
         RESPONSE.redirect(self.absolute_url())
 
-    
+
 class DiscussionItem( Document
                     , DefaultDublinCoreImpl
                     ):
@@ -85,7 +95,8 @@ class DiscussionItem( Document
         Class for content which is a response to other content.
     """
 
-    __implements__ = ( PortalContent.__implements__
+    __implements__ = ( DiscussionResponse
+                     , PortalContent.__implements__
                      , DefaultDublinCoreImpl.__implements__
                      )
 
@@ -94,11 +105,12 @@ class DiscussionItem( Document
     allow_discussion    = 1
     creator             = 'unknown'
     in_reply_to         = None
+    # XXX this is wrong, it precludes the use of a normal workflow.
     review_state        ='published'
 
     security = ClassSecurityInfo()
 
-    security.declareProtected( CMFCorePermissions.View, 'Creator' )
+    security.declareProtected(View, 'Creator')
     def Creator( self ):
         """
             We need to return user who replied, rather than executable
@@ -106,11 +118,11 @@ class DiscussionItem( Document
         """
         #   XXX:  revisit if Creator becomes "real" attribute for stock DC.
         return self.creator
-    
+
     #
     #   DiscussionResponse interface
     #
-    security.declareProtected( CMFCorePermissions.View, 'inReplyTo' )
+    security.declareProtected(View, 'inReplyTo')
     def inReplyTo( self, REQUEST=None ):
         """
             Return the Discussable object to which we are a reply.
@@ -120,7 +132,7 @@ class DiscussionItem( Document
               - We are a "top-level" reply to a non-DiscussionItem piece
                 of content;  in this case, our 'in_reply_to' field will
                 be None.
-            
+
               - We are a nested reply;  in this case, our 'in_reply_to'
                 field will be the ID of the parent DiscussionItem.
         """
@@ -128,7 +140,7 @@ class DiscussionItem( Document
         talkback = tool.getDiscussionFor( self )
         return talkback._getReplyParent( self.in_reply_to )
 
-    security.declarePrivate( CMFCorePermissions.View, 'setReplyTo' )
+    security.declarePrivate(View, 'setReplyTo')
     def setReplyTo( self, reply_to ):
         """
             Make this object a response to the passed object.
@@ -137,8 +149,8 @@ class DiscussionItem( Document
             self.in_reply_to = reply_to.getId()
         else:
             self.in_reply_to = None
-    
-    security.declareProtected( CMFCorePermissions.View, 'parentsInThread' )
+
+    security.declareProtected(View, 'parentsInThread')
     def parentsInThread( self, size=0 ):
         """
             Return the list of items which are "above" this item in
@@ -168,6 +180,8 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
         hold the discussion threads.
     """
 
+    __implements__ = Discussable
+
     # for the security machinery to allow traversal
     #__roles__ = None
 
@@ -177,11 +191,11 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
         self.id = 'talkback'
         self._container = PersistentMapping()
 
-    security.declareProtected( CMFCorePermissions.View, 'getId' )
+    security.declareProtected(View, 'getId')
     def getId( self ):
         return self.id
 
-    security.declareProtected( CMFCorePermissions.View, 'getReply' )
+    security.declareProtected(View, 'getReply')
     def getReply( self, reply_id ):
         """
             Return a discussion item, given its ID;  raise KeyError
@@ -190,7 +204,7 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
         return self._container.get( reply_id ).__of__(self)
 
     # Is this right?
-    security.declareProtected( CMFCorePermissions.View, '__bobo_traverse__' )
+    security.declareProtected(View, '__bobo_traverse__')
     def __bobo_traverse__(self, REQUEST, name):
         """
         This will make this container traversable
@@ -240,8 +254,7 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
     #
     #   OFS.ObjectManager query interface.
     #
-    security.declareProtected( CMFCorePermissions.AccessContentsInformation
-                             , 'objectIds' )
+    security.declareProtected(AccessContentsInformation, 'objectIds')
     def objectIds( self, spec=None ):
         """
             Return a list of the ids of our DiscussionItems.
@@ -251,8 +264,7 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
         return self._container.keys()
 
 
-    security.declareProtected( CMFCorePermissions.AccessContentsInformation
-                             , 'objectItems' )
+    security.declareProtected(AccessContentsInformation, 'objectItems')
     def objectItems(self, spec=None):
         """
             Return a list of (id, subobject) tuples for our DiscussionItems.
@@ -265,8 +277,7 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
         return r
 
 
-    security.declareProtected( CMFCorePermissions.AccessContentsInformation
-                             , 'objectValues' )
+    security.declareProtected(AccessContentsInformation, 'objectValues')
     def objectValues(self):
         """
             Return a list of our DiscussionItems.
@@ -276,7 +287,7 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
     #
     #   Discussable interface
     #
-    security.declareProtected( CMFCorePermissions.ReplyToItem, 'createReply' )
+    security.declareProtected(ReplyToItem, 'createReply')
     def createReply( self, title, text, Creator=None ):
         """
             Create a reply in the proper place
@@ -297,12 +308,12 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
         item.__of__( self ).indexObject()
 
         item.setReplyTo( self._getDiscussable() )
- 
+
         self._container[ id ] = item
 
         return id
 
-    security.declareProtected( CMFCorePermissions.ManagePortal, 'deleteReply' )
+    security.declareProtected(ManagePortal, 'deleteReply')
     def deleteReply( self, reply_id ):
         """ Remove a reply from this container """
         if self._container.has_key( reply_id ):
@@ -321,18 +332,18 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
             del self._container[reply_id]
 
 
-    security.declareProtected( CMFCorePermissions.View, 'hasReplies' )
+    security.declareProtected(View, 'hasReplies')
     def hasReplies( self, content_obj ):
         """
             Test to see if there are any dicussion items
         """
         outer = self._getDiscussable( outer=1 )
-        if content_obj == outer: 
+        if content_obj == outer:
             return not not len( self._container )
         else:
-            return not not len( content_obj.talkback._getReplyResults() ) 
+            return not not len( content_obj.talkback._getReplyResults() )
 
-    security.declareProtected( CMFCorePermissions.View, 'replyCount' )
+    security.declareProtected(View, 'replyCount')
     def replyCount( self, content_obj ):
         """ How many replies do i have? """
         outer = self._getDiscussable( outer=1 )
@@ -358,7 +369,7 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
 
         return count
 
-    security.declareProtected( CMFCorePermissions.View, 'getReplies' )
+    security.declareProtected(View, 'getReplies')
     def getReplies( self ):
         """
             Return a sequence of the DiscussionResponse objects which are
@@ -373,15 +384,15 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
 
         return objects
 
-    security.declareProtected( CMFCorePermissions.View, 'quotedContents' )
+    security.declareProtected(View, 'quotedContents')
     def quotedContents(self):
         """
             Return this object's contents in a form suitable for inclusion
             as a quote in a response.
         """
- 
+
         return ""
-    
+
     #
     #   Utility methods
     #
@@ -396,7 +407,7 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
             return outer
         parent = self._container[ in_reply_to ].__of__( aq_inner( self ) )
         return parent.__of__( outer )
-        
+
 
     security.declarePrivate( '_getDiscussable' )
     def _getDiscussable( self, outer=0 ):
@@ -423,10 +434,11 @@ class DiscussionItemContainer( Persistent, Implicit, Traversable ):
         a = result.append
         for key, value in self._container.items():
             if value.in_reply_to == in_reply_to:
-                a( key )
+                a( ( key, value ) )
+
+        result.sort( lambda a, b: cmp(a[1].creation_date, b[1].creation_date) )
+
+        return [ x[0] for x in result ]
 
-        return result
 
 InitializeClass( DiscussionItemContainer )
-
-
