@@ -19,11 +19,12 @@ from Products.CMFCore.WorkflowCore import WorkflowAction
 from Products.CMFCore.interfaces.DublinCore import DublinCore
 from Products.CMFCore.interfaces.DublinCore import CatalogableDublinCore
 from Products.CMFCore.interfaces.DublinCore import MutableDublinCore
+from Products.CMFCore.utils import getToolByName
 
 from utils import tuplize, _dtmldir, semi_split
 from Globals import InitializeClass, DTMLFile
 from AccessControl import ClassSecurityInfo
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore.CMFCorePermissions import ModifyPortalContent
 
 _marker=[]
 
@@ -103,8 +104,8 @@ class DefaultDublinCoreImpl( PropertyManager ):
         #       *all* owners
         "Dublin Core element - resource creator"
         owner = self.getOwner()
-        if hasattr( owner, 'getUserName' ):
-            return owner.getUserName()
+        if hasattr( owner, 'getId' ):
+            return owner.getId()
         return 'No owner'
 
     security.declarePublic( 'Subject' )
@@ -115,7 +116,11 @@ class DefaultDublinCoreImpl( PropertyManager ):
     security.declarePublic( 'Publisher' )
     def Publisher( self ):
         "Dublin Core element - resource publisher"
-        # XXX: fixme using 'portal_metadata'
+        portal_metadata = getToolByName( self,'portal_metadata', None )
+
+        if portal_metadata is not None:
+          return portal_metadata.getPublisher()
+
         return 'No publisher'
 
     security.declarePublic( 'Description' )
@@ -214,8 +219,8 @@ class DefaultDublinCoreImpl( PropertyManager ):
             WebDAV needs this to do the Right Thing (TM).
         """
         return self.Format()
-    __FLOOR_DATE = DateTime( 1000, 0 ) # alwasy effective
 
+    __FLOOR_DATE = DateTime( 1970, 0 ) # always effective
 
     security.declarePublic( 'isEffective' )
     def isEffective( self, date ):
@@ -309,65 +314,56 @@ class DefaultDublinCoreImpl( PropertyManager ):
                 attrib = DateTime( attrib )
         return attrib
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'setTitle' )
+    security.declareProtected(ModifyPortalContent, 'setTitle')
     def setTitle( self, title ):
         "Dublin Core element - resource name"
         self.title = title
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'setSubject' )
+    security.declareProtected(ModifyPortalContent, 'setSubject')
     def setSubject( self, subject ):
         "Dublin Core element - resource keywords"
         self.subject = tuplize( 'subject', subject )
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'setDescription' )
+    security.declareProtected(ModifyPortalContent, 'setDescription')
     def setDescription( self, description ):
         "Dublin Core element - resource summary"
         self.description = description
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'setContributors' )
+    security.declareProtected(ModifyPortalContent, 'setContributors')
     def setContributors( self, contributors ):
         "Dublin Core element - additional contributors to resource"
         # XXX: fixme
         self.contributors = tuplize('contributors', contributors, semi_split)
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'setEffectiveDate' )
+    security.declareProtected(ModifyPortalContent, 'setEffectiveDate')
     def setEffectiveDate( self, effective_date ):
         """
             Dublin Core element - date resource becomes effective.
         """
         self.effective_date = self._datify( effective_date )
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'setExpirationDate' )
+    security.declareProtected(ModifyPortalContent, 'setExpirationDate')
     def setExpirationDate( self, expiration_date ):
         """
             Dublin Core element - date resource expires.
         """
         self.expiration_date = self._datify( expiration_date )
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'setFormat' )
+    security.declareProtected(ModifyPortalContent, 'setFormat')
     def setFormat( self, format ):
         """
             Dublin Core element - resource format
         """
         self.format = format
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'setLanguage' )
+    security.declareProtected(ModifyPortalContent, 'setLanguage')
     def setLanguage( self, language ):
         """
             Dublin Core element - resource language
         """
         self.language = language
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'setRights' )
+    security.declareProtected(ModifyPortalContent, 'setRights')
     def setRights( self, rights ):
         """
             Dublin Core element - resource copyright
@@ -412,12 +408,10 @@ class DefaultDublinCoreImpl( PropertyManager ):
         if rights is not _marker:
             self.setRights( rights )
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'manage_metadata' )
+    security.declareProtected(ModifyPortalContent, 'manage_metadata')
     manage_metadata = DTMLFile( 'zmi_metadata', _dtmldir )
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'manage_editMetadata' )
+    security.declareProtected(ModifyPortalContent, 'manage_editMetadata')
     def manage_editMetadata( self
                            , title
                            , subject
@@ -441,8 +435,7 @@ class DefaultDublinCoreImpl( PropertyManager ):
                                 + '/manage_metadata'
                                 + '?manage_tabs_message=Metadata+updated.' )
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'editMetadata' )
+    security.declareProtected(ModifyPortalContent, 'editMetadata')
     def editMetadata(self
                    , title=''
                    , subject=()
@@ -458,7 +451,11 @@ class DefaultDublinCoreImpl( PropertyManager ):
         used to be:  editMetadata = WorkflowAction(_editMetadata)
         Need to add check for webDAV locked resource for TTW methods.
         """
-        self.failIfLocked()
+        # as per bug #69, we cant assume they use the webdav
+        # locking interface, and fail gracefully if they dont
+        if hasattr(self, 'failIfLocked'):
+            self.failIfLocked()
+
         self._editMetadata(title=title
                      , subject=subject
                      , description=description
