@@ -1,21 +1,20 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
-""" Favorites are references to other objects within the same CMF site..
+""" Favorites are references to other objects within the same CMF site.
 
-$Id: Favorite.py,v 1.16.4.2 2002/08/03 19:30:29 efge Exp $
+$Id: Favorite.py,v 1.19.4.2 2004/04/22 17:47:50 sidnei Exp $
 """
 
-import string
 import urlparse
 
 from Globals import InitializeClass
@@ -27,34 +26,35 @@ from Products.CMFCore.CMFCorePermissions import View, ModifyPortalContent
 from DublinCore import DefaultDublinCoreImpl
 from Link import Link
 
-factory_type_information = ( { 'id'             : 'Favorite'
-                             , 'meta_type'      : 'Favorite'
-                             , 'description'    : """\
-A Favorite is a Link to an intra-portal resource."""
-                             , 'icon'           : 'link_icon.gif'
-                             , 'product'        : 'CMFDefault'
-                             , 'factory'        : 'addFavorite'
-                             , 'immediate_view' : 'metadata_edit_form'
-                             , 'actions'        :
-                                ( { 'id'            : 'view'
-                                  , 'name'          : 'View'
-                                  , 'action'        : 'favorite_view'
-                                  , 'permissions'   : ( View, )
-                                  }
-                                , { 'id'            : 'edit'
-                                  , 'name'          : 'Edit'
-                                  , 'action'        : 'link_edit_form'
-                                  , 'permissions'   : ( ModifyPortalContent, )
-                                  }
-                                , { 'id'            : 'metadata'
-                                  , 'name'          : 'Metadata'
-                                  , 'action'        : 'metadata_edit_form'
-                                  , 'permissions'   : ( ModifyPortalContent, )
-                                  }
-                                )
-                             }
-                           ,
-                           )
+factory_type_information = (
+  { 'id'             : 'Favorite'
+  , 'meta_type'      : 'Favorite'
+  , 'description'    : """\
+A Favorite is a Link to an intra-portal resource.
+"""
+  , 'icon'           : 'link_icon.gif'
+  , 'product'        : 'CMFDefault'
+  , 'factory'        : 'addFavorite'
+  , 'immediate_view' : 'metadata_edit_form'
+  , 'actions'        : ( { 'id'            : 'view'
+                         , 'name'          : 'View'
+                         , 'action': 'string:${object_url}/favorite_view'
+                         , 'permissions'   : ( View, )
+                         }
+                       , { 'id'            : 'edit'
+                         , 'name'          : 'Edit'
+                         , 'action': 'string:${object_url}/link_edit_form'
+                         , 'permissions'   : ( ModifyPortalContent, )
+                         }
+                       , { 'id'            : 'metadata'
+                         , 'name'          : 'Metadata'
+                         , 'action': 'string:${object_url}/metadata_edit_form'
+                         , 'permissions'   : ( ModifyPortalContent, )
+                         }
+                       )
+  }
+,
+)
 
 def addFavorite(self, id, title='', remote_url='', description=''):
     """
@@ -116,7 +116,7 @@ class Favorite( Link ):
     security.declareProtected(View, 'getObject')
     def getObject(self):
         """
-        Return the actual object that the Favorite is 
+        Return the actual object that the Favorite is
         linking to
         """
         portal_url = getToolByName(self, 'portal_url')
@@ -136,7 +136,7 @@ class Favorite( Link ):
             remote_url=urlparse.urlunparse(t)
         # if URL begins with site URL, remove site URL
         portal_url = getToolByName(self, 'portal_url').getPortalPath()
-        i=string.find(remote_url, portal_url)
+        i = remote_url.find(portal_url)
         if i==0:
             remote_url=remote_url[len(portal_url):]
         # if site is still absolute, make it relative
