@@ -1,20 +1,20 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
- 
-"""
-This module implements a portal-managed File class.  It is based on
+""" This module implements a portal-managed File class.  It is based on
 Zope's built-in File object, but modifies the behaviour slightly to
 make it more Portal-friendly.
+
+$Id: File.py,v 1.25.4.4 2004/08/07 19:24:09 shh Exp $
 """
 
 from Globals import InitializeClass
@@ -23,47 +23,45 @@ from AccessControl import ClassSecurityInfo
 from Products.CMFCore.PortalContent import PortalContent
 from DublinCore import DefaultDublinCoreImpl
 
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore.CMFCorePermissions import View
+from Products.CMFCore.CMFCorePermissions import ModifyPortalContent
 from Products.CMFCore.WorkflowCore import WorkflowAction
 
 
-factory_type_information = ( { 'id'             : 'File'
-                             , 'meta_type'      : 'Portal File'
-                             , 'description'    : """\
-File objects can contain arbitrary downloadable files."""
-                             , 'icon'           : 'file_icon.gif'
-                             , 'product'        : 'CMFDefault'
-                             , 'factory'        : 'addFile'
-                             , 'immediate_view' : 'metadata_edit_form'
-                             , 'actions'        :
-                                ( { 'id'            : 'view'
-                                  , 'name'          : 'View'
-                                  , 'action'        : 'file_view'
-                                  , 'permissions'   : (
-                                      CMFCorePermissions.View, )
-                                  }
-                                , { 'id'            : 'download'
-                                  , 'name'          : 'Download'
-                                  , 'action'        : ''
-                                  , 'permissions'   : (
-                                      CMFCorePermissions.View, )
-                                  }
-                                , { 'id'            : 'edit'
-                                  , 'name'          : 'Edit'
-                                  , 'action'        : 'file_edit_form'
-                                  , 'permissions'   : (
-                                      CMFCorePermissions.ModifyPortalContent, )
-                                  }
-                                , { 'id'            : 'metadata'
-                                  , 'name'          : 'Metadata'
-                                  , 'action'        : 'metadata_edit_form'
-                                  , 'permissions'   : (
-                                      CMFCorePermissions.ModifyPortalContent, )
-                                  }
-                                )
-                             }
-                           ,
-                           )
+factory_type_information = (
+  { 'id'             : 'File'
+  , 'meta_type'      : 'Portal File'
+  , 'description'    : """\
+File objects can contain arbitrary downloadable files.
+"""
+  , 'icon'           : 'file_icon.gif'
+  , 'product'        : 'CMFDefault'
+  , 'factory'        : 'addFile'
+  , 'immediate_view' : 'metadata_edit_form'
+  , 'actions'        : ( { 'id'            : 'view'
+                         , 'name'          : 'View'
+                         , 'action': 'string:${object_url}/file_view'
+                         , 'permissions'   : (View,)
+                         }
+                       , { 'id'            : 'download'
+                         , 'name'          : 'Download'
+                         , 'action': 'string:${object_url}'
+                         , 'permissions'   : (View,)
+                         }
+                       , { 'id'            : 'edit'
+                         , 'name'          : 'Edit'
+                         , 'action': 'string:${object_url}/file_edit_form'
+                         , 'permissions'   : (ModifyPortalContent,)
+                         }
+                       , { 'id'            : 'metadata'
+                         , 'name'          : 'Metadata'
+                         , 'action': 'string:${object_url}/metadata_edit_form'
+                         , 'permissions'   : (ModifyPortalContent,)
+                         }
+                       )
+  }
+,
+)
 
 import OFS.Image
 
@@ -96,7 +94,7 @@ def addFile( self
                , description, contributors, effective_date, expiration_date
                , format, language, rights
                )
-    
+
     # Add the File instance to self
     self._setObject(id, fobj)
 
@@ -122,7 +120,7 @@ class File( OFS.Image.File
     # gnashing of teeth and fraying of nerves.  Don't do it.
     #
     # Really.
-    # 
+    #
     # Note that if you use getId() to retrieve an object's ID, you will avoid
     # this problem altogether. getId is the new way, accessing .id is
     # deprecated.
@@ -130,7 +128,7 @@ class File( OFS.Image.File
     __implements__ = ( PortalContent.__implements__
                      , DefaultDublinCoreImpl.__implements__
                      )
-    
+
     meta_type='Portal File'
     effective_date = expiration_date = None
     _isDiscussable = 1
@@ -159,7 +157,7 @@ class File( OFS.Image.File
                                , contributors, effective_date, expiration_date
                                , format, language, rights )
 
-    security.declareProtected(CMFCorePermissions.View, 'SearchableText')
+    security.declareProtected(View, 'SearchableText')
     def SearchableText(self):
         """
         SeachableText is used for full text seraches of a portal.  It
@@ -173,6 +171,12 @@ class File( OFS.Image.File
         OFS.Image.File.manage_afterAdd(self, item, container)
         PortalContent.manage_afterAdd(self, item, container)
 
+    security.declarePrivate('manage_afterClone')
+    def manage_afterClone(self, item):
+        """Both of my parents have an afterClone method"""
+        OFS.Image.File.manage_afterClone(self, item)
+        PortalContent.manage_afterClone(self, item)
+
     security.declarePrivate('manage_beforeDelete')
     def manage_beforeDelete(self, item, container):
         """Both of my parents have a beforeDelete method"""
@@ -206,9 +210,7 @@ class File( OFS.Image.File
         if self._isNotEmpty(file):
             self.manage_upload(file)
 
-        self.setFormat(self.content_type)
-
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'edit')
+    security.declareProtected(ModifyPortalContent, 'edit')
     def edit(self, precondition='', file=''):
         """ Update and reindex. """
         self._edit( precondition, file )
@@ -216,13 +218,13 @@ class File( OFS.Image.File
 
     edit = WorkflowAction(edit)
 
-    security.declareProtected(CMFCorePermissions.View, 'download')
+    security.declareProtected(View, 'download')
     def download(self, REQUEST, RESPONSE):
         """Download this item.
-        
+
         Calls OFS.Image.File.index_html to perform the actual transfer after
         first setting Content-Disposition to suggest a filename.
-        
+
         This method is deprecated, use the URL of this object itself. Because
         the default view of a File object is to download, rather than view,
         this method is obsolete. Also note that certain browsers do not deal
@@ -234,12 +236,20 @@ class File( OFS.Image.File
                            'attachment; filename=%s' % self.getId())
         return OFS.Image.File.index_html(self, REQUEST, RESPONSE)
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'PUT')
+    security.declareProtected(View, 'Format')
+    def Format(self):
+        """ Dublin Core element - resource format """
+        return self.content_type
+
+    security.declareProtected(ModifyPortalContent, 'setFormat')
+    def setFormat(self, format):
+        """ Dublin Core element - resource format """
+        self.manage_changeProperties(content_type=format)
+
+    security.declareProtected(ModifyPortalContent, 'PUT')
     def PUT(self, REQUEST, RESPONSE):
         """ Handle HTTP (and presumably FTP?) PUT requests """
         OFS.Image.File.PUT( self, REQUEST, RESPONSE )
         self.reindexObject()
 
-
 InitializeClass(File)
-
