@@ -1,19 +1,19 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
- 
-"""
-This module implements a portal-managed Image class.  It is based on
+""" This module implements a portal-managed Image class. It is based on
 Zope's built-in Image object.
+
+$Id: Image.py,v 1.23.4.5 2004/08/07 19:24:09 shh Exp $
 """
 
 from Globals import InitializeClass
@@ -22,40 +22,39 @@ from AccessControl import ClassSecurityInfo
 from Products.CMFCore.PortalContent import PortalContent
 from DublinCore import DefaultDublinCoreImpl
 
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore.CMFCorePermissions import View
+from Products.CMFCore.CMFCorePermissions import ModifyPortalContent
 from Products.CMFCore.WorkflowCore import WorkflowAction
 
-factory_type_information = ( { 'id'             : 'Image'
-                             , 'meta_type'      : 'Portal Image'
-                             , 'description'    : """\
-Image objects can be embedded in Portal documents."""
-                             , 'icon'           : 'image_icon.gif'
-                             , 'product'        : 'CMFDefault'
-                             , 'factory'        : 'addImage'
-                             , 'immediate_view' : 'metadata_edit_form'
-                             , 'actions'        :
-                                ( { 'id'            : 'view'
-                                  , 'name'          : 'View'
-                                  , 'action'        : 'image_view'
-                                  , 'permissions'   : (
-                                      CMFCorePermissions.View, )
-                                  }
-                                , { 'id'            : 'edit'
-                                  , 'name'          : 'Edit'
-                                  , 'action'        : 'image_edit_form'
-                                  , 'permissions'   : (
-                                      CMFCorePermissions.ModifyPortalContent, )
-                                  }
-                                , { 'id'            : 'metadata'
-                                  , 'name'          : 'Metadata'
-                                  , 'action'        : 'metadata_edit_form'
-                                  , 'permissions'   : (
-                                      CMFCorePermissions.ModifyPortalContent, )
-                                  }
-                                )
-                             }
-                           ,
-                           )
+factory_type_information = (
+  { 'id'             : 'Image'
+  , 'meta_type'      : 'Portal Image'
+  , 'description'    : """\
+Image objects can be embedded in Portal documents.
+"""
+  , 'icon'           : 'image_icon.gif'
+  , 'product'        : 'CMFDefault'
+  , 'factory'        : 'addImage'
+  , 'immediate_view' : 'metadata_edit_form'
+  , 'actions'        : ( { 'id'            : 'view'
+                         , 'name'          : 'View'
+                         , 'action': 'string:${object_url}/image_view'
+                         , 'permissions'   : (View,)
+                         }
+                       , { 'id'            : 'edit'
+                         , 'name'          : 'Edit'
+                         , 'action': 'string:${object_url}/image_edit_form'
+                         , 'permissions'   : (ModifyPortalContent,)
+                         }
+                       , { 'id'            : 'metadata'
+                         , 'name'          : 'Metadata'
+                         , 'action': 'string:${object_url}/metadata_edit_form'
+                         , 'permissions'   : (ModifyPortalContent,)
+                         }
+                       )
+  }
+,
+)
 
 import OFS.Image
 
@@ -88,7 +87,7 @@ def addImage( self
                 , description, contributors, effective_date, expiration_date
                 , format, language, rights
                 )
-    
+
     # Add the Image instance to self
     self._setObject(id, iobj)
 
@@ -113,7 +112,7 @@ class Image( OFS.Image.Image
     # gnashing of teeth and fraying of nerves.  Don't do it.
     #
     # Really.
-    # 
+    #
     # Note that if you use getId() to retrieve an object's ID, you will avoid
     # this problem altogether. getId is the new way, accessing .id is
     # deprecated.
@@ -121,7 +120,7 @@ class Image( OFS.Image.Image
     __implements__ = ( PortalContent.__implements__
                      , DefaultDublinCoreImpl.__implements__
                      )
-    
+
     meta_type='Portal Image'
     effective_date = expiration_date = None
     _isDiscussable = 1
@@ -150,7 +149,7 @@ class Image( OFS.Image.Image
                                , contributors, effective_date, expiration_date
                                , format, language, rights )
 
-    security.declareProtected(CMFCorePermissions.View, 'SearchableText')
+    security.declareProtected(View, 'SearchableText')
     def SearchableText(self):
         """
             SeachableText is used for full text seraches of a portal.
@@ -164,6 +163,12 @@ class Image( OFS.Image.Image
         OFS.Image.Image.manage_afterAdd(self, item, container)
         PortalContent.manage_afterAdd(self, item, container)
 
+    security.declarePrivate('manage_afterClone')
+    def manage_afterClone(self, item):
+        """Both of my parents have an afterClone method"""
+        OFS.Image.Image.manage_afterClone(self, item)
+        PortalContent.manage_afterClone(self, item)
+
     security.declarePrivate('manage_beforeDelete')
     def manage_beforeDelete(self, item, container):
         """Both of my parents have a beforeDelete method"""
@@ -197,9 +202,7 @@ class Image( OFS.Image.Image
         if self._isNotEmpty(file):
             self.manage_upload(file)
 
-        self.setFormat(self.content_type)
-
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'edit')
+    security.declareProtected(ModifyPortalContent, 'edit')
     def edit(self, precondition='', file=''):
         """ Update and reindex. """
         self._edit( precondition, file )
@@ -207,7 +210,7 @@ class Image( OFS.Image.Image
 
     edit = WorkflowAction(edit)
 
-    security.declareProtected(CMFCorePermissions.View, 'index_html')
+    security.declareProtected(View, 'index_html')
     def index_html(self, REQUEST, RESPONSE):
         """
         Display the image, with or without standard_html_[header|footer],
@@ -217,12 +220,20 @@ class Image( OFS.Image.Image
         #    return self.view(self, REQUEST)
         return OFS.Image.Image.index_html(self, REQUEST, RESPONSE)
 
-    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'PUT')
+    security.declareProtected(View, 'Format')
+    def Format(self):
+        """ Dublin Core element - resource format """
+        return self.content_type
+
+    security.declareProtected(ModifyPortalContent, 'setFormat')
+    def setFormat(self, format):
+        """ Dublin Core element - resource format """
+        self.manage_changeProperties(content_type=format)
+
+    security.declareProtected(ModifyPortalContent, 'PUT')
     def PUT(self, REQUEST, RESPONSE):
         """ Handle HTTP (and presumably FTP?) PUT requests """
         OFS.Image.Image.PUT( self, REQUEST, RESPONSE )
         self.reindexObject()
 
 InitializeClass(Image)
-
-
