@@ -1,66 +1,65 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
 """ Link instances represent explicit links-as-content.
 
-$Id: Link.py,v 1.20.4.4 2002/08/04 04:04:44 efge Exp $
+$Id: Link.py,v 1.26.4.3 2004/07/25 20:12:17 shh Exp $
 """
 
-import string
 import urlparse
 
 from Globals import InitializeClass, DTMLFile
 from AccessControl import ClassSecurityInfo
 
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore.CMFCorePermissions import View
+from Products.CMFCore.CMFCorePermissions import ModifyPortalContent
 from Products.CMFCore.PortalContent import PortalContent, NoWL
 from Products.CMFCore.PortalContent import ResourceLockedError
 from Products.CMFCore.WorkflowCore import WorkflowAction
 from Products.CMFCore.utils import keywordsplitter
+from Products.CMFCore.utils import contributorsplitter
 
 from DublinCore import DefaultDublinCoreImpl
 from utils import formatRFC822Headers, parseHeadersBody, _dtmldir
 
-factory_type_information = ( { 'id'             : 'Link'
-                             , 'meta_type'      : 'Link'
-                             , 'description'    : """\
-Link items are URLs that come with additional information."""
-                             , 'icon'           : 'link_icon.gif'
-                             , 'product'        : 'CMFDefault'
-                             , 'factory'        : 'addLink'
-                             , 'immediate_view' : 'metadata_edit_form'
-                             , 'actions'        :
-                                ( { 'id'            : 'view'
-                                  , 'name'          : 'View'
-                                  , 'action'        : 'link_view'
-                                  , 'permissions'   : (
-                                      CMFCorePermissions.View, )
-                                  }
-                                , { 'id'            : 'edit'
-                                  , 'name'          : 'Edit'
-                                  , 'action'        : 'link_edit_form'
-                                  , 'permissions'   : (
-                                      CMFCorePermissions.ModifyPortalContent, )
-                                  }
-                                , { 'id'            : 'metadata'
-                                  , 'name'          : 'Metadata'
-                                  , 'action'        : 'metadata_edit_form'
-                                  , 'permissions'   : (
-                                      CMFCorePermissions.ModifyPortalContent, )
-                                  }
-                                )
-                             }
-                           ,
-                           )
+factory_type_information = (
+  { 'id'             : 'Link'
+  , 'meta_type'      : 'Link'
+  , 'description'    : """\
+Link items are annotated URLs.
+"""
+  , 'icon'           : 'link_icon.gif'
+  , 'product'        : 'CMFDefault'
+  , 'factory'        : 'addLink'
+  , 'immediate_view' : 'metadata_edit_form'
+  , 'actions'        : ( { 'id'            : 'view'
+                         , 'name'          : 'View'
+                         , 'action': 'string:${object_url}/link_view'
+                         , 'permissions'   : (View,)
+                         }
+                       , { 'id'            : 'edit'
+                         , 'name'          : 'Edit'
+                         , 'action': 'string:${object_url}/link_edit_form'
+                         , 'permissions'   : (ModifyPortalContent,)
+                         }
+                       , { 'id'            : 'metadata'
+                         , 'name'          : 'Metadata'
+                         , 'action': 'string:${object_url}/metadata_edit_form'
+                         , 'permissions'   : (ModifyPortalContent,)
+                         }
+                       )
+  }
+,
+)
 
 
 def addLink( self
@@ -107,12 +106,10 @@ class Link( PortalContent
         self._edit(remote_url)
         self.format=self.URL_FORMAT
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'manage_edit' )
+    security.declareProtected(ModifyPortalContent, 'manage_edit')
     manage_edit = DTMLFile( 'zmi_editLink', _dtmldir )
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent
-                             , 'manage_editLink' )
+    security.declareProtected(ModifyPortalContent, 'manage_editLink')
     def manage_editLink( self, remote_url, REQUEST=None ):
         """
             Update the Link via the ZMI.
@@ -146,7 +143,7 @@ class Link( PortalContent
             url = urlparse.urlunparse(tokens)
         self.remote_url = url
 
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent, 'edit' )
+    security.declareProtected(ModifyPortalContent, 'edit')
     def edit(self, remote_url ):
         """ Update and reindex. """
         self._edit( remote_url )
@@ -154,14 +151,14 @@ class Link( PortalContent
 
     edit = WorkflowAction( edit )
 
-    security.declareProtected( CMFCorePermissions.View, 'SearchableText' )
+    security.declareProtected(View, 'SearchableText')
     def SearchableText(self):
         """
             text for indexing
         """
         return "%s %s" % (self.title, self.description)
 
-    security.declareProtected( CMFCorePermissions.View, 'getRemoteUrl' )
+    security.declareProtected(View, 'getRemoteUrl')
     def getRemoteUrl(self):
         """
             returns the remote URL of the Link
@@ -172,16 +169,18 @@ class Link( PortalContent
     def _writeFromPUT( self, body ):
         headers = {}
         headers, body = parseHeadersBody(body, headers)
-        lines = string.split( body, '\n' )
+        lines = body.split('\n')
         self.edit( lines[0] )
         headers['Format'] = self.URL_FORMAT
         new_subject = keywordsplitter(headers)
         headers['Subject'] = new_subject or self.Subject()
+        new_contrib = contributorsplitter(headers)
+        headers['Contributors'] = new_contrib or self.Contributors()
         haveheader = headers.has_key
         for key, value in self.getMetadataHeaders():
-            if key != 'Format' and not haveheader(key):
+            if not haveheader(key):
                 headers[key] = value
-        
+
         self._editMetadata(title=headers['Title'],
                           subject=headers['Subject'],
                           description=headers['Description'],
@@ -192,9 +191,9 @@ class Link( PortalContent
                           language=headers['Language'],
                           rights=headers['Rights'],
                           )
-        
+
     ## FTP handlers
-    security.declareProtected( CMFCorePermissions.ModifyPortalContent, 'PUT')
+    security.declareProtected(ModifyPortalContent, 'PUT')
     def PUT(self, REQUEST, RESPONSE):
         """
             Handle HTTP / WebDAV / FTP PUT requests.
@@ -212,25 +211,22 @@ class Link( PortalContent
             RESPONSE.setStatus(423)
             return RESPONSE
 
-    security.declareProtected( CMFCorePermissions.View, 'manage_FTPget' )
+    security.declareProtected(View, 'manage_FTPget')
     def manage_FTPget(self):
         """
             Get the link as text for WebDAV src / FTP download.
         """
-        join = string.join
-        lower = string.lower
         hdrlist = self.getMetadataHeaders()
         hdrtext = formatRFC822Headers( hdrlist )
         bodytext = '%s\n\n%s' % ( hdrtext, self.getRemoteUrl() )
 
         return bodytext
 
-    security.declareProtected( CMFCorePermissions.View, 'get_size' )
+    security.declareProtected(View, 'get_size')
     def get_size( self ):
         """
-            Used for FTP and apparently the ZMI now too 
+            Used for FTP and apparently the ZMI now too
         """
         return len(self.manage_FTPget())
 
 InitializeClass( Link )
-
