@@ -1,23 +1,23 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
 """ Default implementation of CMFCore.
 
-$Id: __init__.py,v 1.12.32.4 2002/11/21 17:56:18 mj Exp $
+$Id: __init__.py,v 1.21.16.1 2004/04/22 17:47:50 sidnei Exp $
 """
+
 from Products import CMFCore
 
 from Products.CMFCore.CMFCorePermissions import AddPortalContent
-import Products.CMFCore
 
 from Products.CMFCore.DirectoryView import registerDirectory
 from Products.CMFCore.utils import initializeBasesPhase1
@@ -27,10 +27,10 @@ from Products.CMFCore.utils import ContentInit
 from Products.CMFCore.utils import registerIcon
 
 import utils
- 
+
 import Portal
 import Document
-import Document 
+import Link
 import NewsItem
 import File
 import Image
@@ -42,7 +42,6 @@ import PropertiesTool
 import MembershipTool
 import MetadataTool
 import RegistrationTool
-import URLTool
 import DublinCore
 import DiscussionTool
 import SyndicationTool
@@ -111,7 +110,6 @@ tools = ( DiscussionTool.DiscussionTool
         , MembershipTool.MembershipTool
         , RegistrationTool.RegistrationTool
         , PropertiesTool.PropertiesTool
-        , URLTool.URLTool
         , MetadataTool.MetadataTool
         , SyndicationTool.SyndicationTool
         )
@@ -158,5 +156,14 @@ def initialize( context ):
                 , globals()
                 )
 
-    context.registerHelp()
+    # make registerHelp work with 2 directories
+    help = context.getProductHelp()
+    lastRegistered = help.lastRegistered
+    context.registerHelp(directory='help', clear=1)
+    context.registerHelp(directory='interfaces', clear=1)
+    if help.lastRegistered != lastRegistered:
+        help.lastRegistered = None
+        context.registerHelp(directory='help', clear=1)
+        help.lastRegistered = None
+        context.registerHelp(directory='interfaces', clear=0)
     context.registerHelpTitle('CMF Default Help')
