@@ -2,7 +2,7 @@
 ##parameters=title,text
 ##title=Reply to content
 
-Creator = context.portal_membership.getAuthenticatedMember().getUserName()
+Creator = context.portal_membership.getAuthenticatedMember().getId()
 replyID = context.createReply( title = title
                              , text = text
                              , Creator = Creator
@@ -11,4 +11,3 @@ replyID = context.createReply( title = title
 target = '%s/%s' % (context.absolute_url(), replyID)
 
 context.REQUEST.RESPONSE.redirect(target)
-
