@@ -1,5 +1,11 @@
+from unittest import TestCase, TestSuite, makeSuite, main
+
 import Zope
-from unittest import TestSuite, makeSuite, main
+try:
+    from Interface.Verify import verifyClass
+except ImportError:
+    # for Zope versions before 2.6.0
+    from Interface import verify_class_implementation as verifyClass
 
 from Products.CMFCore.tests.base.testcase import \
      SecurityTest
@@ -12,19 +18,45 @@ from Products.CMFCore.tests.base.dummy import DummyContent
 
 from Products.CMFCore.CatalogTool import CatalogTool
 from Products.CMFCore.TypesTool import TypesTool
+from Products.CMFCore.URLTool import URLTool
 from Products.CMFCore.WorkflowTool import WorkflowTool
 
-from Products.CMFDefault.DiscussionTool import \
-     DiscussionTool, DiscussionNotAllowed
+from Products.CMFDefault.DiscussionTool import DiscussionTool
+from Products.CMFDefault.DiscussionTool import DiscussionNotAllowed
+from Products.CMFDefault.DiscussionItem import DiscussionItem
+from Products.CMFDefault.DiscussionItem import DiscussionItemContainer
+
+
+class DiscussionItemTests(TestCase):
+
+    def test_interface(self):
+        from Products.CMFCore.interfaces.Dynamic \
+                import DynamicType as IDynamicType
+        from Products.CMFCore.interfaces.Contentish \
+                import Contentish as IContentish
+        from Products.CMFCore.interfaces.Discussions \
+                import DiscussionResponse as IDiscussionResponse
+
+        verifyClass(IDynamicType, DiscussionItem)
+        verifyClass(IContentish, DiscussionItem)
+        verifyClass(IDiscussionResponse, DiscussionItem)
+
+
+class DiscussionItemContainerTests(TestCase):
+
+    def test_interface(self):
+        from Products.CMFCore.interfaces.Discussions \
+                import Discussable as IDiscussable
+
+        verifyClass(IDiscussable, DiscussionItemContainer)
 
-from Products.CMFDefault.URLTool import URLTool
 
 class DiscussionTests( SecurityTest ):
 
     def setUp( self ):
-        
+
         SecurityTest.setUp(self)
-        
+
         root = self.root
         root._setObject( 'portal_discussion', DiscussionTool() )
         self.discussion_tool = root.portal_discussion
@@ -32,14 +64,14 @@ class DiscussionTests( SecurityTest ):
         self.catalog_tool = root.portal_catalog
         root._setObject( 'portal_url', URLTool() )
         self.url_tool = root.portal_url
-        root._setObject( 'portal_workflow', WorkflowTool() ) 
+        root._setObject( 'portal_workflow', WorkflowTool() )
         self.workflow_tool = root.portal_workflow
         root._setObject( 'portal_types', TypesTool() )
         types_tool = self.types_tool = root.portal_types
         try: root._delObject('test')
         except AttributeError: pass
         root._setObject( 'test', DummyContent( 'test', catalog=1 ) )
-            
+
     def test_policy( self ):
 
         test = self.root.test
@@ -78,7 +110,7 @@ class DiscussionTests( SecurityTest ):
         test.allow_discussion = 1
         assert self.discussion_tool.getDiscussionFor( test )
         assert test.talkback
-    
+
     def test_nestedReplies( self ):
         test = self.root.test
         test.allow_discussion = 1
@@ -200,6 +232,8 @@ class DiscussionTests( SecurityTest ):
 
 def test_suite():
     return TestSuite((
+        makeSuite( DiscussionItemTests ),
+        makeSuite( DiscussionItemContainerTests ),
         makeSuite( DiscussionTests ),
         ))
 
