@@ -1,4 +1,11 @@
 from unittest import TestSuite, makeSuite, main
+
+try:
+    from Interface.Verify import verifyClass
+except ImportError:
+    # for Zope versions before 2.6.0
+    from Interface import verify_class_implementation as verifyClass
+
 from StringIO import StringIO
 from re import compile
 
@@ -15,6 +22,7 @@ from Products.CMFCore.tests.base.content import STX_NO_HEADERS
 from Products.CMFCore.tests.base.content import STX_NO_HEADERS_BUT_COLON
 from Products.CMFCore.tests.base.content import SIMPLE_STRUCTUREDTEXT
 from Products.CMFCore.tests.base.content import SIMPLE_HTML
+from Products.CMFCore.tests.base.content import SIMPLE_XHTML
 
 from Products.CMFDefault.Document import Document
 
@@ -32,30 +40,25 @@ class DocumentTests(RequestTest):
         self.assertEqual( d.text_format, 'structured-text' )
         self.assertEqual( d._stx_level, 1 )
 
-    def test_BasicHtmlPUT(self):
-        self.REQUEST['BODY'] = BASIC_HTML
+    def test_editBasicHTML(self):
         d = self.d
-        d.PUT(self.REQUEST, self.RESPONSE)
+        d.edit('html', BASIC_HTML)
+        self.failUnless( hasattr(d, 'cooked_text') )
         self.assertEqual( d.Format(), 'text/html' )
-        self.assertEqual( d.title, 'Title in tag' )
         self.assertEqual( d.text.find('</body>'), -1 )
-        self.assertEqual( d.Description(), 'Describe me' )
-        self.assertEqual( len(d.Contributors()), 3 )
-        self.assertEqual( d.Contributors()[-1], 'Benotz, Larry J (larry@benotz.stuff)' )
+        self.assertEqual( d.cooked_text, '\n  <h1>Not a lot here</h1>\n ' )
 
         # Since the format is html, the STX level operands should
         # have no effect.
         ct = d.CookedBody(stx_level=3, setlevel=1)
         self.assertEqual( d._stx_level, 1 )
 
-        subj = list(d.Subject())
-        self.assertEqual( len(subj), 4 )
-        subj.sort()
-        self.assertEqual( subj, [ 'content management'
-                                , 'framework'
-                                , 'unit tests'
-                                , 'zope'
-                                ] )
+    def test_editSimpleXHTML(self):
+        d = self.d
+        d.edit('html', SIMPLE_XHTML)
+        self.failUnless( hasattr(d, 'cooked_text') )
+        self.assertEqual( d.Format(), 'text/html' )
+        self.assertEqual( d.cooked_text, '\n  <h1>Not a lot here</h1>\n ')
 
     def test_UpperedHtml(self):
         self.REQUEST['BODY'] = BASIC_HTML.upper()
@@ -68,7 +71,7 @@ class DocumentTests(RequestTest):
         self.assertEqual( len(d.Contributors()), 3 )
 
     def test_EntityInTitle(self):
-        self.REQUEST['BODY'] = ENTITY_IN_TITLE 
+        self.REQUEST['BODY'] = ENTITY_IN_TITLE
         d = self.d
         d.PUT(self.REQUEST, self.RESPONSE)
         self.assertEqual( d.title, '&Auuml;rger' )
@@ -86,16 +89,6 @@ class DocumentTests(RequestTest):
         self.assertEqual( d.Format(), 'text/html' )
         self.assertEqual( d.Description(), 'Describe me' )
 
-    def test_EditStripHTMLToBody(self):
-        # bodyfind should strip away everything but the contents of the body
-        # tag.
-        self.REQUEST['BODY'] = BASIC_HTML
-        d = self.d
-        d.PUT(self.REQUEST, self.RESPONSE)
-        self.failUnless( hasattr(d, 'cooked_text') )
-        self.assertEqual( d.Format(), 'text/html' )
-        self.assertEquals(d.cooked_text, '\n  <h1>Not a lot here</h1>\n ')
-
     def test_EditPlainDocumentWithEmbeddedHTML(self):
         d = self.d
         d.edit('structured-text', FAUX_HTML_LEADING_TEXT)
@@ -126,17 +119,17 @@ class DocumentTests(RequestTest):
         file = StringIO( html )
         d.edit(text_format='html', text='', file=file)
         self.assertEqual( d.CookedBody(), body )
-        
+
     def test_plain_text(self):
         """test that plain text forrmat works"""
-        d = self.d 
+        d = self.d
         d.edit(text_format='plain', text='*some plain text*\nwith a newline')
-        self.assertEqual( d.CookedBody(), '*some plain text*<br>with a newline')
+        self.assertEqual( d.CookedBody(), '*some plain text*<br />with a newline')
 
     def test_EditStructuredTextWithHTML(self):
         d = self.d
         d.edit(text_format='structured-text', text=STX_WITH_HTML)
-        
+
         self.assertEqual( d.Format(), 'text/plain' )
 
     def test_StructuredText(self):
@@ -217,7 +210,7 @@ class DocumentTests(RequestTest):
         self.assertEqual( d.EditableBody(), STX_NO_HEADERS )
         self.failUnless( d.CookedBody() )
         self.assertEqual( d.Format(), 'text/plain' )
-    
+
     def test_STX_NoHeaders( self ):
         self.REQUEST['BODY']=STX_NO_HEADERS
         d = self.d
@@ -233,14 +226,14 @@ class DocumentTests(RequestTest):
         self.failUnless( 'STX' in d.Subject() )
 
         d.PUT(self.REQUEST, self.RESPONSE)
-        
+
         self.assertEqual( d.Format(), 'text/plain' )
         self.assertEqual( d.Title(), 'Plain STX' )
         self.assertEqual( d.Description(), 'Look, Ma, no headers!' )
         self.assertEqual( len( d.Subject() ), 2 )
         self.failUnless( 'plain' in d.Subject() )
         self.failUnless( 'STX' in d.Subject() )
-    
+
     def test_STX_NoHeaders_but_colon( self ):
         d = self.d
         d.editMetadata( title="Plain STX"
@@ -250,7 +243,7 @@ class DocumentTests(RequestTest):
 
         d.edit(text_format='structured-text', text=STX_NO_HEADERS_BUT_COLON)
         self.assertEqual( d.EditableBody(), STX_NO_HEADERS_BUT_COLON )
-    
+
     def test_ZMI_edit( self ):
         d = self.d
         d.editMetadata( title="Plain STX"
@@ -262,8 +255,50 @@ class DocumentTests(RequestTest):
                              , text=STX_NO_HEADERS_BUT_COLON)
         self.assertEqual( d.EditableBody(), STX_NO_HEADERS_BUT_COLON )
 
+    def test_Format_methods(self):
+        d = self.d
+        d.setFormat('plain')
+        self.assertEqual( d.text_format, 'plain' )
+        self.assertEqual( d.Format(), 'text/plain' )
+        d.setFormat( d.Format() )
+        self.assertEqual( d.text_format, 'plain' )
 
-class TestFTPGet( RequestTest ):
+        d.setFormat('structured-text')
+        self.assertEqual( d.text_format, 'structured-text' )
+        self.assertEqual( d.Format(), 'text/plain' )
+        d.setFormat( d.Format() )
+        self.assertEqual( d.text_format, 'structured-text' )
+
+        d.setFormat('html')
+        self.assertEqual( d.text_format, 'html' )
+        self.assertEqual( d.Format(), 'text/html' )
+        d.setFormat( d.Format() )
+        self.assertEqual( d.text_format, 'html' )
+
+        d.setFormat('foo')
+        self.assertEqual( d.text_format, 'structured-text' )
+
+    def test_interface(self):
+        from Products.CMFCore.interfaces.Dynamic \
+                import DynamicType as IDynamicType
+        from Products.CMFCore.interfaces.Contentish \
+                import Contentish as IContentish
+        from Products.CMFCore.interfaces.DublinCore \
+                import DublinCore as IDublinCore
+        from Products.CMFCore.interfaces.DublinCore \
+                import CatalogableDublinCore as ICatalogableDublinCore
+        from Products.CMFCore.interfaces.DublinCore \
+                import MutableDublinCore as IMutableDublinCore
+
+        verifyClass(IDynamicType, Document)
+        verifyClass(IContentish, Document)
+        verifyClass(IDublinCore, Document)
+        verifyClass(ICatalogableDublinCore, Document)
+        # XXX: verifyClass doesn't work with WorkflowMethod wrappers.
+        # verifyClass(IMutableDublinCore, Document)
+
+
+class DocumentFTPGetTests(RequestTest):
 
     def testHTML( self ):
         self.REQUEST['BODY']=BASIC_HTML
@@ -281,7 +316,7 @@ class TestFTPGet( RequestTest ):
         title_pattern = compile( r'<title>(.*)</title>' )
         simple_headers = []
         while simple_lines and simple_lines[0] != '<BODY>':
-            header = simple_lines[0].strip().lower() 
+            header = simple_lines[0].strip().lower()
             match = meta_pattern.search( header )
             if match:
                 simple_headers.append( match.groups() )
@@ -339,14 +374,49 @@ class TestFTPGet( RequestTest ):
         for header in simple_headers:
             self.failUnless( header in get_headers )
 
-class TestDocumentPUT(RequestTest):
+
+class DocumentPUTTests(RequestTest):
 
     def setUp(self):
         RequestTest.setUp(self)
         self.d = Document('foo')
 
+    def test_PUTBasicHTML(self):
+        self.REQUEST['BODY'] = BASIC_HTML
+        d = self.d
+        r = d.PUT(self.REQUEST, self.RESPONSE)
+        self.failUnless( hasattr(d, 'cooked_text') )
+        self.assertEqual( d.Format(), 'text/html' )
+        self.assertEqual( d.title, 'Title in tag' )
+        self.assertEqual( d.text.find('</body>'), -1 )
+        self.assertEqual( d.Description(), 'Describe me' )
+        self.assertEqual( len(d.Contributors()), 3 )
+        self.assertEqual( d.Contributors()[-1],
+                          'Benotz, Larry J (larry@benotz.stuff)' )
+        self.assertEqual( d.cooked_text, '\n  <h1>Not a lot here</h1>\n ' )
+        self.assertEqual( r.status, 204 )
+
+        subj = list(d.Subject())
+        self.assertEqual( len(subj), 4 )
+        subj.sort()
+        self.assertEqual( subj, [ 'content management'
+                                , 'framework'
+                                , 'unit tests'
+                                , 'zope'
+                                ] )
+
+    def test_PUTSimpleXHTML(self):
+        self.REQUEST['BODY'] = SIMPLE_XHTML
+        d = self.d
+        r = d.PUT(self.REQUEST, self.RESPONSE)
+        self.failUnless( hasattr(d, 'cooked_text') )
+        self.assertEqual( d.Format(), 'text/html' )
+        self.assertEqual( d.Description(), 'Describe me' )
+        self.assertEqual( d.cooked_text, '\n  <h1>Not a lot here</h1>\n ' )
+        self.assertEqual( r.status, 204 )
+
     def test_PutStructuredTextWithHTML(self):
-            
+
         self.REQUEST['BODY'] = STX_WITH_HTML
 
         r = self.d.PUT(self.REQUEST, self.RESPONSE)
@@ -362,31 +432,43 @@ class TestDocumentPUT(RequestTest):
         self.assertEqual( r.status, 204 )
 
     def test_PutHtmlWithDoctype(self):
-        
+
         html = '%s\n\n  \n   %s' % (DOCTYPE, BASIC_HTML)
         self.REQUEST['BODY'] = html
-        
+
         r = self.d.PUT(self.REQUEST, self.RESPONSE)
         self.assertEqual( self.d.Format(), 'text/html' )
         self.assertEqual( self.d.Description(), 'Describe me' )
         self.assertEqual( r.status, 204 )
 
-    def test_PutHtml(self):
-        
-        self.REQUEST['BODY'] = BASIC_HTML
-        r = self.d.PUT(self.REQUEST, self.RESPONSE)
-        self.assertEqual( self.d.Format(), 'text/html' )
-        self.assertEqual( self.d.Description(), 'Describe me' )
+    def test_PutHtmlWithoutMetadata(self):
+        self.REQUEST['BODY'] = HTML_TEMPLATE % {'title': 'Foo', 'body': 'Bar'}
+        d = self.d
+        r = d.PUT(self.REQUEST, self.RESPONSE)
+        self.assertEqual( d.Title(), 'Foo' )
+        self.assertEqual( d.Format(), 'text/html' )
+        self.assertEqual( d.Description(), '' )
+        self.assertEqual( d.Subject(), () )
+        self.assertEqual( d.Contributors(), () )
+        self.assertEqual( d.EffectiveDate(), 'None' )
+        self.assertEqual( d.ExpirationDate(), 'None' )
+        self.assertEqual( d.Language(), '' )
+        self.assertEqual( d.Rights(), '' )
         self.assertEqual( r.status, 204 )
 
+    def test_default_format( self ):
+        d = self.d
+        self.assertEqual( d.Format(), 'text/plain' )
+        self.assertEqual( d.text_format, 'structured-text' )
+
+
 
 def test_suite():
     return TestSuite((
         makeSuite(DocumentTests),
-        makeSuite(TestFTPGet),
-        makeSuite(TestDocumentPUT),
+        makeSuite(DocumentFTPGetTests),
+        makeSuite(DocumentPUTTests),
         ))
 
 if __name__ == '__main__':
     main(defaultTest='test_suite')
-
