@@ -55,7 +55,7 @@ class LinkTests(TestCase):
     def test_StructuredText( self ):
         d = Link('foo')
         d._writeFromPUT( body=BASIC_STRUCTUREDTEXT )
-        
+
         self.assertEqual( d.Title(), 'Zope Community' )
         self.assertEqual( d.Description()
                         , 'Link to the Zope Community website.' )
@@ -68,7 +68,7 @@ class LinkTests(TestCase):
         d._writeFromPUT( body=STX_W_CONTINUATION )
         rnlinesplit = compile( r'\r?\n?' )
         desc_lines = rnlinesplit.split( d.Description() )
-        
+
         self.assertEqual( d.Title(), 'Zope Community' )
         self.assertEqual( desc_lines[0]
                         , 'Link to the Zope Community website,' )
@@ -77,6 +77,19 @@ class LinkTests(TestCase):
         self.assertEqual( len(d.Subject()), 3 )
         self.assertEqual( d.getRemoteUrl(), 'http://www.zope.org' )
 
+    def test_PutWithoutMetadata(self):
+        d = Link( 'foo' )
+        d._writeFromPUT( body='' )
+        self.assertEqual( d.Title(), '' )
+        self.assertEqual( d.Format(), 'text/url' )
+        self.assertEqual( d.Description(), '' )
+        self.assertEqual( d.Subject(), () )
+        self.assertEqual( d.Contributors(), () )
+        self.assertEqual( d.EffectiveDate(), 'None' )
+        self.assertEqual( d.ExpirationDate(), 'None' )
+        self.assertEqual( d.Language(), '' )
+        self.assertEqual( d.Rights(), '' )
+
     def test_fixupMissingScheme(self):
         table = {
             'http://foo.com':      'http://foo.com',
