@@ -1,6 +1,20 @@
+##############################################################################
+#
+# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
+#
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE
+#
+##############################################################################
+""" Utility functions.
+
+$Id: utils.py,v 1.19.16.1 2004/04/22 17:47:50 sidnei Exp $
 """
-    Utility functions.
-"""
+
 from sgmllib import SGMLParser
 import re
 import os
@@ -10,26 +24,10 @@ from AccessControl import ModuleSecurityInfo
 
 security = ModuleSecurityInfo( 'Products.CMFDefault.utils' )
 
-security.declarePublic( 'formatRFC822Headers'
-                      , 'parseHeadersBody'
-                      , 'semi_split'
-                      , 'comma_split'
-                      , 'seq_strip'
-                      , 'tuplize'
-                      , 'scrubHTML'
-                      , 'isHTMLSafe'
-                      , 'bodyfinder'
-                      , 'html_headcheck'
-                      )
-
-security.declarePrivate( '_dtmldir'
-                       , '_bodyre'
-                       , '_endbodyre'
-                       , '_htfinder'
-                       )
-
+security.declarePrivate('_dtmldir')
 _dtmldir = os.path.join( package_home( globals() ), 'dtml' )
 
+security.declarePublic('formatRFC822Headers')
 def formatRFC822Headers( headers ):
 
     """ Convert the key-value pairs in 'headers' to valid RFC822-style
@@ -47,6 +45,7 @@ def formatRFC822Headers( headers ):
     return '\r\n'.join( munged )
 
 
+security.declarePublic('parseHeadersBody')
 def parseHeadersBody( body, headers=None, rc=re.compile( r'\n|\r\n' ) ):
 
     """ Parse any leading 'RFC-822'-ish headers from an uploaded
@@ -117,19 +116,22 @@ def parseHeadersBody( body, headers=None, rc=re.compile( r'\n|\r\n' ) ):
     return headers, '\n'.join( lines[ i+1: ] )
 
 
+security.declarePublic('semi_split')
 def semi_split(s):
 
     """ Split 's' on semicolons.
     """
     return map(lambda x: x.strip(), s.split( ';' ) )
 
+security.declarePublic('comma_split')
 def comma_split(s):
 
     """ Split 's' on commas.
     """
     return map(lambda x: x.strip(), s.split( ',') )
 
-def seq_strip (seq, stripper=lambda x: x.strip() ):
+security.declarePublic('seq_strip')
+def seq_strip(seq, stripper=lambda x: x.strip() ):
 
     """ Strip a sequence of strings.
     """
@@ -141,6 +143,7 @@ def seq_strip (seq, stripper=lambda x: x.strip() ):
 
     raise ValueError, "%s of unsupported sequencetype %s" % ( seq, type( seq ) )
 
+security.declarePublic('tuplize')
 def tuplize( valueName, value, splitter=lambda x: x.strip() ):
 
     if type( value ) == type( () ):
@@ -215,7 +218,7 @@ class SimpleHTMLParser( SGMLParser ):
 
         if name:
             self.metatags[ name ] = content
-    
+
     def unknown_startag( self, tag, attrs ):
 
         self.setliteral()
@@ -231,10 +234,10 @@ class SimpleHTMLParser( SGMLParser ):
 # These are the HTML tags that we will leave intact
 VALID_TAGS = { 'a'          : 1
              , 'b'          : 1
-             , 'base'       : 1
+             , 'base'       : 0
              , 'blockquote' : 1
              , 'body'       : 1
-             , 'br'         : 1
+             , 'br'         : 0
              , 'caption'    : 1
              , 'cite'       : 1
              , 'code'       : 1
@@ -250,14 +253,14 @@ VALID_TAGS = { 'a'          : 1
              , 'h5'         : 1
              , 'h6'         : 1
              , 'head'       : 1
-             , 'hr'         : 1
+             , 'hr'         : 0
              , 'html'       : 1
              , 'i'          : 1
-             , 'img'        : 1
+             , 'img'        : 0
              , 'kbd'        : 1
              , 'li'         : 1
            # , 'link'       : 1 type="script" hoses us
-             , 'meta'       : 1
+             , 'meta'       : 0
              , 'ol'         : 1
              , 'p'          : 1
              , 'pre'        : 1
@@ -318,7 +321,7 @@ class StrippingParser( SGMLParser ):
 
         """ Delete all tags except for legal ones.
         """
-        if VALID_TAGS.get( tag ):
+        if VALID_TAGS.has_key(tag):
 
             self.result = self.result + '<' + tag
 
@@ -333,7 +336,10 @@ class StrippingParser( SGMLParser ):
                 self.result = '%s %s="%s"' % (self.result, k, v)
 
             endTag = '</%s>' % tag
-            self.result = self.result + '>'
+            if VALID_TAGS.get(tag):
+                self.result = self.result + '>'
+            else:
+                self.result = self.result + ' />'
 
         elif NASTY_TAGS.get( tag ):
             raise IllegalHTML, 'Dynamic tag "%s" not allowed.' % tag
@@ -348,6 +354,7 @@ class StrippingParser( SGMLParser ):
             self.result = "%s</%s>" % (self.result, tag)
             remTag = '</%s>' % tag
 
+security.declarePublic('scrubHTML')
 def scrubHTML( html ):
 
     """ Strip illegal HTML tags from string text.
@@ -357,6 +364,7 @@ def scrubHTML( html ):
     parser.close()
     return parser.result
 
+security.declarePublic('isHTMLSafe')
 def isHTMLSafe( html ):
 
     """ Would current HTML be permitted to be saved?
@@ -368,39 +376,38 @@ def isHTMLSafe( html ):
     else:
         return 1
 
-_bodyre = re.compile( r'^\s*<html.*<body.*?>', re.DOTALL | re.I )
+security.declarePublic('bodyfinder')
+def bodyfinder(text):
+    """ Return body or unchanged text if no body tags found.
 
-_endbodyre = re.compile( r'</body', re.DOTALL | re.I )
-
-def bodyfinder( text ):
-
-    bod = _bodyre.search( text )
-    if not bod:
-        return text
-
-    end = _endbodyre.search( text )
-    if not end:
-        return text
-    else:
-        return text[bod.end():end.start()]
-
-_htfinder = re.compile( r'<html', re.DOTALL | re.I )
-
-def html_headcheck( html ):
-
-    """ Return 'true' if document looks HTML-ish enough.
+    Always use html_headcheck() first.
     """
-    if not _htfinder.search(html):
+    lowertext = text.lower()
+    bodystart = lowertext.find('<body')
+    if bodystart == -1:
+        return text
+    bodystart = lowertext.find('>', bodystart) + 1
+    if bodystart == 0:
+        return text
+    bodyend = lowertext.rfind('</body>', bodystart)
+    if bodyend == -1:
+        return text
+    return text[bodystart:bodyend]
+
+security.declarePrivate('_htfinder')
+_htfinder = re.compile(r'(\s|(<[^<>]*?>))*<html.*<body.*?>.*</body>',
+                       re.DOTALL)
+
+security.declarePublic('html_headcheck')
+def html_headcheck(html):
+    """ Return 'true' if document looks HTML-ish enough.
+
+    If true bodyfinder() will be able to find the HTML body.
+    """
+    lowerhtml = html.lower()
+    if lowerhtml.find('<html') == -1:
+        return 0
+    elif _htfinder.match(lowerhtml):
+        return 1
+    else:
         return 0
-
-    lines = re.split(r'[\n\r]+?', html)
-
-    for line in lines:
-        line = line.strip()
-
-        if not line:
-            continue
-        elif line.lower().startswith( '<html' ):
-            return 1
-        elif line[0] != '<':
-            return 0
