@@ -1,18 +1,18 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
 """ List Criterion: A criterion that is a list
 
-$Id: ListCriterion.py,v 1.9.10.2 2002/08/01 19:07:57 tseaver Exp $
+$Id: ListCriterion.py,v 1.12.18.1 2004/04/22 17:47:55 sidnei Exp $
 """
 
 from Products.CMFTopic.AbstractCriterion import AbstractCriterion
@@ -20,7 +20,7 @@ from Products.CMFTopic.interfaces import Criterion
 from Products.CMFTopic.Topic import Topic
 from Products.CMFTopic import TopicPermissions
 
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore.CMFCorePermissions import View
 
 from Globals import InitializeClass
 from AccessControl import ClassSecurityInfo
@@ -80,7 +80,7 @@ class ListCriterion( AbstractCriterion ):
 
         self.operator = operator
 
-    security.declareProtected( CMFCorePermissions.View, 'getCriteriaItems' )
+    security.declareProtected(View, 'getCriteriaItems')
     def getCriteriaItems( self ):
         """
             Return a tuple of query elements to be passed to the catalog
@@ -89,7 +89,7 @@ class ListCriterion( AbstractCriterion ):
         # filter out empty strings
         result = []
 
-        value = tuple( filter( None, self.value ) ) 
+        value = tuple( filter( None, self.value ) )
         if not value:
             return ()
         result.append( ( self.field, self.value ), )
