@@ -1,18 +1,18 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
 """ Simple int-matching criterion
 
-$Id: SimpleIntCriterion.py,v 1.8.20.1 2002/08/01 19:07:57 tseaver Exp $
+$Id: SimpleIntCriterion.py,v 1.10.18.1 2004/04/22 17:47:55 sidnei Exp $
 """
 
 from Products.CMFTopic import TopicPermissions
@@ -20,7 +20,7 @@ from Products.CMFTopic.AbstractCriterion import AbstractCriterion
 from Products.CMFTopic.Topic import Topic
 from Products.CMFTopic.interfaces import Criterion
 
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore.CMFCorePermissions import View
 
 from Globals import InitializeClass
 from AccessControl import ClassSecurityInfo
@@ -28,7 +28,7 @@ from AccessControl import ClassSecurityInfo
 class SimpleIntCriterion( AbstractCriterion ):
     """
         Represent a simple field-match for an integer value, including
-        catalog range searches.    
+        catalog range searches.
     """
     __implements__ = ( Criterion, )
 
@@ -82,7 +82,7 @@ class SimpleIntCriterion( AbstractCriterion ):
         from string import strip, split # XXX: WAAAA! 2.3 compatibility
 
         if type( value ) == type( '' ):
-           value = strip( value )
+            value = strip( value )
 
         if not value:
             # An empty string was passed in, which evals to None
@@ -108,7 +108,7 @@ class SimpleIntCriterion( AbstractCriterion ):
             self.value = int( value )
             self.direction = None
 
-    security.declareProtected( CMFCorePermissions.View, 'getCriteriaItems' )
+    security.declareProtected(View, 'getCriteriaItems')
     def getCriteriaItems( self ):
         """
             Return a tuple of query elements to be passed to the catalog
