@@ -1,18 +1,18 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
 """ Simple string-matching criterion class
 
-$Id: SimpleStringCriterion.py,v 1.8.20.1 2002/08/01 19:07:57 tseaver Exp $
+$Id: SimpleStringCriterion.py,v 1.10.18.1 2004/04/22 17:47:55 sidnei Exp $
 """
 
 from Products.CMFTopic import TopicPermissions
@@ -20,7 +20,7 @@ from Products.CMFTopic.AbstractCriterion import AbstractCriterion
 from Products.CMFTopic.Topic import Topic
 from Products.CMFTopic.interfaces import Criterion
 
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFCore.CMFCorePermissions import View
 
 from Globals import InitializeClass
 from AccessControl import ClassSecurityInfo
@@ -41,22 +41,22 @@ class SimpleStringCriterion( AbstractCriterion ):
         self.id = id
         self.field = field
         self.value = ''
-        
+
     security.declareProtected( TopicPermissions.ChangeTopics, 'getEditForm' )
     def getEditForm( self ):
         """
             Return the skinned name of the edit form.
         """
         return 'ssc_edit'
-    
+
     security.declareProtected( TopicPermissions.ChangeTopics, 'edit' )
     def edit( self, value ):
         """
             Update the value we are to match up against.
         """
         self.value = str( value )
-    
-    security.declareProtected( CMFCorePermissions.View, 'getCriteriaItems' )
+
+    security.declareProtected(View, 'getCriteriaItems')
     def getCriteriaItems( self ):
         """
             Return a sequence of criteria items, used by Topic.buildQuery.
