@@ -1,66 +1,64 @@
 ##############################################################################
 #
 # Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
-# 
+#
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
 # FOR A PARTICULAR PURPOSE
-# 
+#
 ##############################################################################
 """ Topic: Canned catalog queries
 
-$Id: Topic.py,v 1.28.20.2 2002/08/01 19:07:57 tseaver Exp $
+$Id: Topic.py,v 1.32.4.2 2004/04/22 17:47:56 sidnei Exp $
 """
 
-from Products.CMFTopic import TopicPermissions
-
-from Products.CMFCore import CMFCorePermissions
+from Products.CMFTopic.TopicPermissions import ChangeTopics
+from Products.CMFTopic.TopicPermissions import AddTopics
+from Products.CMFCore.CMFCorePermissions import View
 from Products.CMFCore.utils import _checkPermission, _getViewFor,getToolByName
 from Products.CMFCore.PortalFolder import PortalFolder
 
-from Globals import HTMLFile, package_home, InitializeClass
+from Globals import InitializeClass
 from AccessControl import ClassSecurityInfo
 from Acquisition import aq_parent, aq_inner, aq_base
-from ComputedAttribute import ComputedAttribute
 
-import os
 
 # Factory type information -- makes Topic objects play nicely
 # with the Types Tool (portal_types )
-factory_type_information = \
-( { 'id'                : 'Topic'
-  , 'content_icon'      : 'topic_icon.gif'
-  , 'meta_type'         : 'Portal Topic'
-  , 'description'       : 'Topics are canned queries for organizing content '
-                          'with up to date queries into the catalog.'
-  , 'product'           : 'CMFTopic'
-  , 'factory'           : 'addTopic'
-  , 'immediate_view'    : 'topic_edit_form'
-  , 'actions'           :
-    ( { 'id'            : 'view'
-      , 'name'          : 'View'
-      , 'action'        : 'topic_view'
-      , 'permissions'   : (CMFCorePermissions.View, )
-      }
-    , { 'id'            : 'edit'
-      , 'name'          : 'Edit'
-      , 'action'        : 'topic_edit_form'
-      , 'permissions'   : (TopicPermissions.ChangeTopics, )
-      }
-    , { 'id'            : 'criteria'
-      , 'name'          : 'Criteria'
-      , 'action'        : 'topic_criteria_form'
-      , 'permissions'   : (TopicPermissions.ChangeTopics, )
-      }
-    , { 'id'            : 'subtopics'
-      , 'name'          : 'Subtopics'
-      , 'action'        : 'topic_subtopics_form'
-      , 'permissions'   : (TopicPermissions.ChangeTopics, )
-      }
-    )
+factory_type_information = (
+  { 'id'             : 'Topic'
+  , 'content_icon'   : 'topic_icon.gif'
+  , 'meta_type'      : 'Portal Topic'
+  , 'description'    : 'Topics are canned queries for organizing content '
+                       'with up to date queries into the catalog.'
+  , 'product'        : 'CMFTopic'
+  , 'factory'        : 'addTopic'
+  , 'immediate_view' : 'topic_edit_form'
+  , 'actions'        : ( { 'id'            : 'view'
+                         , 'name'          : 'View'
+                         , 'action': 'string:${object_url}/topic_view'
+                         , 'permissions'   : (View,)
+                         }
+                       , { 'id'            : 'edit'
+                         , 'name'          : 'Edit'
+                         , 'action': 'string:${object_url}/topic_edit_form'
+                         , 'permissions'   : (ChangeTopics,)
+                         }
+                       , { 'id'            : 'criteria'
+                         , 'name'          : 'Criteria'
+                         , 'action': 'string:${object_url}/topic_criteria_form'
+                         , 'permissions'   : (ChangeTopics,)
+                         }
+                       , { 'id'            : 'subtopics'
+                         , 'name'          : 'Subtopics'
+                         , 'action':
+                                   'string:${object_url}/topic_subtopics_form'
+                         , 'permissions'   : (ChangeTopics,)
+                         }
+                       )
   }
 ,
 )
@@ -88,7 +86,7 @@ class Topic( PortalFolder ):
 
     security = ClassSecurityInfo()
 
-    security.declareObjectProtected( CMFCorePermissions.View )
+    security.declareObjectProtected(View)
 
     acquireCriteria = 1
     _criteriaTypes = []
@@ -96,7 +94,7 @@ class Topic( PortalFolder ):
     # Contentish interface methods
     # ----------------------------
 
-    security.declareProtected( CMFCorePermissions.View, 'icon' )
+    security.declareProtected(View, 'icon')
     def icon( self ):
         """
             For the ZMI.
@@ -125,7 +123,7 @@ class Topic( PortalFolder ):
 
     index_html = None  # This special value informs ZPublisher to use __call__
 
-    security.declareProtected( CMFCorePermissions.View, 'view' )
+    security.declareProtected(View, 'view')
     def view( self ):
         """
             Return the default view even if index_html is overridden.
@@ -138,8 +136,8 @@ class Topic( PortalFolder ):
         for mt in self._criteriaTypes:
             result.append( mt.meta_type )
         return tuple( result )
- 
-    security.declareProtected( TopicPermissions.ChangeTopics, 'listCriteria' )
+
+    security.declareProtected(ChangeTopics, 'listCriteria')
     def listCriteria( self ):
         """
             Return a list of our criteria objects.
@@ -147,8 +145,7 @@ class Topic( PortalFolder ):
         return self.objectValues( self._criteria_metatype_ids() )
 
 
-    security.declareProtected( TopicPermissions.ChangeTopics
-                             , 'listCriteriaTypes' )
+    security.declareProtected(ChangeTopics, 'listCriteriaTypes')
     def listCriteriaTypes( self ):
         out = []
         for ct in self._criteriaTypes:
@@ -156,9 +153,8 @@ class Topic( PortalFolder ):
                 'name': ct.meta_type,
                 } )
         return out
-    
-    security.declareProtected( TopicPermissions.ChangeTopics
-                             , 'listAvailableFields' )
+
+    security.declareProtected(ChangeTopics, 'listAvailableFields')
     def listAvailableFields( self ):
         """
             Return a list of available fields for new criteria.
@@ -171,14 +167,14 @@ class Topic( PortalFolder ):
             )
         return availfields
 
-    security.declareProtected( TopicPermissions.ChangeTopics, 'listSubtopics' )
+    security.declareProtected(ChangeTopics, 'listSubtopics')
     def listSubtopics( self ):
         """
             Return a list of our subtopics.
         """
         return self.objectValues( self.meta_type )
 
-    security.declareProtected( TopicPermissions.ChangeTopics, 'edit' )
+    security.declareProtected(ChangeTopics, 'edit')
     def edit( self, acquireCriteria, title=None, description=None ):
         """
             Set the flag which indicates whether to acquire criteria
@@ -188,8 +184,8 @@ class Topic( PortalFolder ):
         if title is not None:
             self.title = title
         self.description = description
-        
-    security.declareProtected( CMFCorePermissions.View, 'buildQuery' )
+
+    security.declareProtected(View, 'buildQuery')
     def buildQuery( self ):
         """
             Construct a catalog query using our criterion objects.
@@ -208,10 +204,10 @@ class Topic( PortalFolder ):
         for criterion in self.listCriteria():
             for key, value in criterion.getCriteriaItems():
                 result[ key ] = value
-        
+
         return result
-    
-    security.declareProtected( CMFCorePermissions.View, 'queryCatalog' )
+
+    security.declareProtected(View, 'queryCatalog')
     def queryCatalog( self, REQUEST=None, **kw ):
         """
             Invoke the catalog using our criteria to augment any passed
@@ -223,7 +219,7 @@ class Topic( PortalFolder ):
 
 
     ### Criteria adding/editing/deleting
-    security.declareProtected( TopicPermissions.ChangeTopics, 'addCriterion' )
+    security.declareProtected(ChangeTopics, 'addCriterion')
     def addCriterion( self, field, criterion_type ):
         """
             Add a new search criterion.
@@ -237,15 +233,14 @@ class Topic( PortalFolder ):
         if crit is None:
             # No criteria type matched passed in value
             raise NameError, 'Unknown Criterion Type: %s' % criterion_type
-        
+
         self._setObject( newid, crit )
 
     # Backwards compatibility (deprecated)
-    security.declareProtected( TopicPermissions.ChangeTopics, 'addCriteria' )
+    security.declareProtected(ChangeTopics, 'addCriteria')
     addCriteria = addCriterion
 
-    security.declareProtected( TopicPermissions.ChangeTopics
-                             , 'deleteCriterion' )
+    security.declareProtected(ChangeTopics, 'deleteCriterion')
     def deleteCriterion( self, criterion_id ):
         """
             Delete selected criterion.
@@ -256,7 +251,7 @@ class Topic( PortalFolder ):
             for cid in criterion_id:
                 self._delObject( cid )
 
-    security.declareProtected( CMFCorePermissions.View, 'getCriterion' )
+    security.declareProtected(View, 'getCriterion')
     def getCriterion( self, criterion_id ):
         """
             Get the criterion object.
@@ -266,7 +261,7 @@ class Topic( PortalFolder ):
         except AttributeError:
             return self._getOb( criterion_id )
 
-    security.declareProtected( TopicPermissions.AddTopics, 'addSubtopic' )
+    security.declareProtected(AddTopics, 'addSubtopic')
     def addSubtopic( self, id ):
         """
             Add a new subtopic.
